@@ -26,40 +26,41 @@
  * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class GlobalBackendMgmt {
-	var $MAINCFG;
-	var $BACKENDS;
+	protected $CORE;
+	public $BACKENDS;
+	private $aInitialized;
 	
 	/**
 	 * Constructor
+	 *
 	 * Initializes all backends
 	 *
-	 * @param	config $MAINCFG
-	 * @author	Lars Michelsen <lars@vertical-visions.de>
+	 * @param   config  $MAINCFG
+	 * @author  Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function GlobalBackendMgmt(&$MAINCFG) {
-		$this->MAINCFG = &$MAINCFG;
+	public function __construct($CORE) {
+		$this->CORE = $CORE;
+		
 		$this->BACKENDS = Array();
 		
-		$this->initBackends();
+		$this->aInitialized = Array();
+		
+		$this->loadBackends();
 		
 		return 0;
 	}
 	
 	/**
-	 * Reads all defined Backend-IDs from the MAINCFG
+	 * Loads all backends and prints an error when no backend defined
 	 *
-	 * @return	Array Backend-IDs
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getBackends() {
-		$ret = Array();
-		foreach($this->MAINCFG->config AS $sec => &$var) {
-			if(preg_match('/^backend_/i', $sec)) {
-				$ret[] = $var['backendid'];
-			}
-		}
+	private function loadBackends() {
+		$aBackends = $this->CORE->getDefinedBackends();
 		
-		return $ret;
+		if(!count($aBackends)) {
+			new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('noBackendDefined'));
+		}
 	}
 	
 	/**
@@ -69,14 +70,13 @@ class GlobalBackendMgmt {
 	 * @return	Boolean	Is Successful?
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function checkBackendExists($backendId,$printErr) {
-		if($backendId != '') {
-			if(file_exists($this->MAINCFG->getValue('paths','class').'GlobalBackend-'.$this->MAINCFG->getValue('backend_'.$backendId,'backendtype').'.php')) {
+	private function checkBackendExists($backendId, $printErr) {
+		if(isset($backendId) && $backendId != '') {
+			if(file_exists($this->CORE->MAINCFG->getValue('paths','class').'GlobalBackend'.$this->CORE->MAINCFG->getValue('backend_'.$backendId,'backendtype').'.php')) {
 				return TRUE;
 			} else {
 				if($printErr == 1) {
-					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'backend:global'));
-					$FRONTEND->messageToUser('ERROR','backendNotExists','BACKENDID~'.$backendId.',BACKENDTYPE~'.$this->MAINCFG->getValue('backend_'.$backendId,'backendtype'));
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('backendNotExists','BACKENDID~'.$backendId.',BACKENDTYPE~'.$this->CORE->MAINCFG->getValue('backend_'.$backendId,'backendtype')));
 				}
 				return FALSE;
 			}
@@ -85,6 +85,26 @@ class GlobalBackendMgmt {
 		}
 	}
 	
+	/**
+	 * Initializes a backend
+	 *
+	 * @return	Boolean	Is Successful?
+	 * @author 	Lars Michelsen <lars@vertical-visions.de>
+	 */
+	private function initializeBackend($backendId) {
+		if($this->checkBackendExists($backendId, 1)) {
+			$backendClass = 'GlobalBackend'.$this->CORE->MAINCFG->getValue('backend_'.$backendId,'backendtype');
+			$this->BACKENDS[$backendId] = new $backendClass($this->CORE,$backendId);
+			
+			// Mark backend as initialized
+			$this->aInitialized[$backendId] = true;
+			
+			return true;
+		} else {
+			return false;
+		}
+	}
+	
 	/**
 	 * Checks for an initialized backend
 	 *
@@ -92,42 +112,19 @@ class GlobalBackendMgmt {
 	 * @return	Boolean	Is Successful?
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function checkBackendInitialized($backendId,$printErr) {
-		if($backendId != '') {
-			if(isset($this->BACKENDS[$backendId]) && is_object($this->BACKENDS[$backendId])) {
-				return TRUE;
+	public function checkBackendInitialized($backendId, $printErr) {
+		if(isset($this->aInitialized[$backendId])) {
+			return TRUE;
+		} else {
+			// Try to initialize backend
+			if($this->initializeBackend($backendId)) {
+				return true;
 			} else {
 				if($printErr == 1) {
-					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'backend:global'));
-					$FRONTEND->messageToUser('ERROR','backendNotInitialized','BACKENDID~'.$backendId.',BACKENDTYPE~'.$this->MAINCFG->getValue('backend_'.$backendId,'backendtype'));
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('backendNotInitialized','BACKENDID~'.$backendId.',BACKENDTYPE~'.$this->CORE->MAINCFG->getValue('backend_'.$backendId,'backendtype')));
 				}
 				return FALSE;
 			}
-		} else {
-			return FALSE;
-		}
-	}
-	
-	/**
-	 * Initializes all backends
-	 *
-	 * @author 	Lars Michelsen <lars@vertical-visions.de>
-	 */
-	function initBackends() {
-		$aBackends = $this->getBackends();
-		
-		if(!count($aBackends)) {
-			$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'backend:global'));
-		    $FRONTEND->messageToUser('ERROR','noBackendDefined');
-		} else {
-			foreach($aBackends AS &$backendId) {
-				if($this->checkBackendExists($backendId,1)) {
-					require($this->MAINCFG->getValue('paths','class').'GlobalBackend-'.$this->MAINCFG->getValue('backend_'.$backendId,'backendtype').'.php');
-					
-					$backendClass = 'GlobalBackend'.$this->MAINCFG->getValue('backend_'.$backendId,'backendtype');
-					$this->BACKENDS[$backendId] = new $backendClass($this->MAINCFG,$backendId);
-				}
-			}
 		}
 	}
 }
