@@ -26,11 +26,17 @@
  * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class GlobalBackground {
-	var $MAINCFG;
-	var $image;
+	protected $CORE;
+	protected $image;
 	
-	function GlobalBackground(&$MAINCFG, $image) {
-		$this->MAINCFG = &$MAINCFG;
+	/**
+	 * Constructor
+	 *
+	 * @param   config  $MAINCFG
+	 * @author  Lars Michelsen <lars@vertical-visions.de>
+	 */
+	public function __construct($CORE, $image) {
+		$this->CORE = $CORE;
 		$this->image = $image;
 	}
 	
@@ -40,10 +46,24 @@ class GlobalBackground {
 	 * @return	String File Name
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getFileName() {
+	public function getFileName() {
 		return $this->image;
 	}
 	
+	/**
+	 * Gets the background file
+	 *
+	 * @return  String  HTML Path to background file
+	 * @author  Lars Michelsen <lars@vertical-visions.de>
+	 */
+	public function getFile() {
+		$sReturn = '';
+		if($this->getFileName() != '' && $this->getFileName() != 'none') {
+			$sReturn = $this->CORE->MAINCFG->getValue('paths', 'htmlmap').$this->getFileName();
+		}
+		return $sReturn;
+	}
+	
 	/**
 	 * Checks for existing map image file
 	 *
@@ -51,16 +71,13 @@ class GlobalBackground {
 	 * @return	Boolean	Is Successful?
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function checkFileExists($printErr) {
+	protected function checkFileExists($printErr) {
 		if($this->image != '') {
-			if(file_exists($this->MAINCFG->getValue('paths', 'map').$this->image)) {
-			//if(@fclose(@fopen($this->MAINCFG->getValue('paths', 'map').$this->image, 'r'))) {
+			if(file_exists($this->CORE->MAINCFG->getValue('paths', 'map').$this->image)) {
 				return TRUE;
 			} else {
 				if($printErr) {
-					//Error Box
-					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:global'));
-					$FRONTEND->messageToUser('ERROR','backgroundNotExists','IMGPATH~'.$this->MAINCFG->getValue('paths', 'map').$this->image);
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('backgroundNotExists','IMGPATH~'.$this->CORE->MAINCFG->getValue('paths', 'map').$this->image));
 				}
 				return FALSE;
 			}
@@ -76,15 +93,13 @@ class GlobalBackground {
 	 * @return	Boolean	Is Successful?
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function checkFileReadable($printErr) {
+	protected function checkFileReadable($printErr) {
 		if($this->image != '') {
-			if($this->checkFileExists($printErr) && is_readable($this->MAINCFG->getValue('paths', 'map').$this->image)) {
+			if($this->checkFileExists($printErr) && is_readable($this->CORE->MAINCFG->getValue('paths', 'map').$this->image)) {
 				return TRUE;
 			} else {
 				if($printErr) {
-					//Error Box
-					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:global'));
-					$FRONTEND->messageToUser('ERROR','backgroundNotReadable','IMGPATH~'.$this->MAINCFG->getValue('paths', 'map').$this->image);
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('backgroundNotReadable','IMGPATH~'.$this->CORE->MAINCFG->getValue('paths', 'map').$this->image));
 				}
 				return FALSE;
 			}
@@ -100,15 +115,13 @@ class GlobalBackground {
 	 * @return	Boolean	Is Successful?
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function checkFileWriteable($printErr) {
+	protected function checkFileWriteable($printErr) {
 		if($this->image != '') {
-			if($this->checkFileExists($printErr) && is_writable($this->MAINCFG->getValue('paths', 'map').$this->image)) {
+			if($this->checkFileExists($printErr) && is_writable($this->CORE->MAINCFG->getValue('paths', 'map').$this->image)) {
 				return TRUE;
 			} else {
 				if($printErr) {
-					//Error Box
-					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:global'));
-					$FRONTEND->messageToUser('ERROR','backgroundNotWriteable','IMGPATH~'.$this->MAINCFG->getValue('paths', 'map').$this->image);
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('backgroundNotWriteable','IMGPATH~'.$this->CORE->MAINCFG->getValue('paths', 'map').$this->image));
 				}
 				return FALSE;
 			}
@@ -124,17 +137,15 @@ class GlobalBackground {
 	 * @return	Boolean	Is Successful?
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function checkFolderWriteable($printErr) {
-		if(is_writable($this->MAINCFG->getValue('paths', 'map'))) {
+	protected function checkFolderWriteable($printErr) {
+		if(is_writable($this->CORE->MAINCFG->getValue('paths', 'map'))) {
 			return TRUE;
 		} else {
 			if($printErr) {
-				//Error Box
-				$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:global'));
-				$FRONTEND->messageToUser('ERROR','backgroundFolderNotWriteable','PATH~'.$this->MAINCFG->getValue('paths', 'map').$this->image);
+				new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('backgroundFolderNotWriteable','PATH~'.$this->CORE->MAINCFG->getValue('paths', 'map').$this->image));
 			}
 			return FALSE;
 		}
 	}
 }
-?>
\ No newline at end of file
+?>
