@@ -27,13 +27,13 @@
  * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class GlobalForm {
-	var $name;
-	var $id;
-	var $method;
-	var $action;
-	var $onSubmit;
-	var $cols;
-	var $enctype;
+	private $name;
+	private $id;
+	private $method;
+	private $action;
+	private $onSubmit;
+	private $cols;
+	private $enctype;
 	
 	/**
 	 * Class Constructor
@@ -41,7 +41,7 @@ class GlobalForm {
 	 * @param 	Array	$prop	Array('name'=>'myform','id'=>'myform','method'=>'POST','action'=>'','onSubmit'=>'','cols'=>'2','enctype'=>''
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function GlobalForm($prop=Array('name'=>'myform','id'=>'myform','method'=>'POST','action'=>'','onSubmit'=>'','cols'=>'2','enctype'=>'')) {
+	public function __construct($prop=Array('name'=>'myform','id'=>'myform','method'=>'POST','action'=>'','onSubmit'=>'','cols'=>'2','enctype'=>'')) {
 		$this->name = $prop['name'];
 		$this->id = $prop['id'];
 		$this->method = (isset($prop['method'])) ? $prop['method']:'';
@@ -59,12 +59,8 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getHiddenField($name,$value) {
-		$ret = Array();
-		
-		$ret[] = '<input type="hidden" name="'.$name.'" value="'.$value.'" />';
-		
-		return $ret;
+	public function getHiddenField($name,$value) {
+		return '<input type="hidden" id="'.$name.'" name="'.$name.'" value="'.$value.'" />';
 	}
 	
 	/**
@@ -74,12 +70,8 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getTitleLine($title) {
-		$ret = Array();
-		
-		$ret[] = '<tr><th colspan="'.$this->cols.'">'.$title.'</th></tr>';
-		
-		return $ret;
+	public function getTitleLine($title) {
+		return '<tr><th colspan="'.$this->cols.'">'.$title.'</th></tr>';
 	}
 	
 	/**
@@ -89,16 +81,12 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getCatLine($title) {
-		$ret = Array();
-		
-		$ret[] = '<tr><th class="cat" colspan="'.$this->cols.'">'.$title.'</th></tr>';
-		
-		return $ret;
+	public function getCatLine($title) {
+		return '<tr><th class="cat" colspan="'.$this->cols.'">'.$title.'</th></tr>';
 	}
 	
 	/**
-	 * Gets an file selection row
+	 * Gets a file selection row
 	 *
 	 * @param 	String 	$label 	Label of the Row
 	 * @param 	String 	$name 	Name of the Field
@@ -106,18 +94,14 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getFileLine($label,$name,$value,$must=FALSE) {
-		$ret = Array();
-		
+	public function getFileLine($label,$name,$value,$must=FALSE) {
 		if($must != FALSE) {
 			$must = 'style="color:red;"';	
 		} else {
 			$must = '';
 		}
 		
-		$ret[] = '<tr><td class="tdlabel" '.$must.'>'.$label.'</td><td class="tdfield"><input type="file" name="'.$name.'" value="'.$value.'" /></td></tr>';
-		
-		return $ret;
+		return '<tr><td class="tdlabel" '.$must.'>'.$label.'</td><td class="tdfield"><input type="file" name="'.$name.'" value="'.$value.'" /></td></tr>';
 	}
 	
 	/**
@@ -130,8 +114,8 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getInputLine($label,$name,$value,$must=FALSE,$onBlur='') {
-		$ret = Array();
+	public function getInputLine($label,$name,$value=NULL,$must=FALSE,$onBlur='',$rowStyle='',$rowClass='') {
+		$ret = '';
 		
 		if($must != FALSE) {
 			$must = 'style="color:red;"';	
@@ -139,9 +123,31 @@ class GlobalForm {
 			$must = '';
 		}
 		
-		$ret[] = '<tr><td class="tdlabel" '.$must.'>'.$label.'</td><td class="tdfield">';
-		$ret = array_merge($ret,$this->getInputField($name,$value,$onBlur));
-		$ret[] = '</td></tr>';
+		if($rowStyle != '') {
+			$style = ' style="'.$rowStyle.'"';
+		} else {
+			$style = '';
+		}
+		
+		if($rowClass != '') {
+			$class = ' class="'.$rowClass.'"';
+		} else {
+			$class = '';
+		}
+		
+		$ret .= '<tr'.$style.$class.'><td class="tdlabel" '.$must.'>'.$label.'</td><td class="tdfield">';
+		$ret .= $this->getInputField($name, '', $onBlur);
+		$ret .= '</td></tr>';
+		
+		if($value !== NULL && $value !== FALSE && $value !== '') {
+			if(is_array($value)) {
+				$value = implode(',',$value);
+			}
+			
+			$ret .= '<script>document.'.$this->name.'.'.$name.'.value="'.$value.'";</script>';
+		} else {
+			$ret .= '<script>toggleDefaultOption(\''.$name.'\');</script>';
+		}
 		
 		return $ret;
 	}
@@ -158,8 +164,8 @@ class GlobalForm {
 	 * @return	Array 		Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getSelectLine($label,$name,$arr,$selected,$must=FALSE,$onChange='',$onBlur='') {
-		$ret = Array();
+	public function getSelectLine($label,$name,$arr,$selected=NULL,$must=FALSE,$onChange='',$onBlur='', $rowStyle='',$rowClass='') {
+		$ret = '';
 		
 		if($must) {
 			$color = ' style="color:red;"';	
@@ -167,9 +173,27 @@ class GlobalForm {
 			$color = '';
 		}
 		
-		$ret[] = '<tr><td class="tdlabel"'.$color.'>'.$label.'</td><td class="tdfield">';
-		$ret = array_merge($ret,$this->getSelectField($name,$arr,$onChange,$must,$onBlur));
-		$ret[] = '</td></tr><script>document.'.$this->name.'.'.$name.'.value="'.$selected.'";</script>';
+		if($rowStyle != '') {
+			$style = ' style="'.$rowStyle.'"';
+		} else {
+			$style = '';
+		}
+		
+		if($rowClass != '') {
+			$class = ' class="'.$rowClass.'"';
+		} else {
+			$class = '';
+		}
+		
+		$ret .= '<tr'.$style.$class.'><td class="tdlabel"'.$color.'>'.$label.'</td><td class="tdfield">';
+		$ret .= $this->getSelectField($name,$arr,$onChange,$must,$onBlur);
+		$ret .= '</td></tr>';
+		
+		if($selected !== NULL && $selected !== FALSE && $selected !== '') { 
+			$ret .= '<script>document.'.$this->name.'.'.$name.'.value="'.$selected.'";</script>';
+		} else {
+			$ret .= '<script>toggleDefaultOption(\''.$name.'\');</script>';
+		}
 		
 		return $ret;
 	}
@@ -181,12 +205,12 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getSubmitLine($label) {
-		$ret = Array();
+	public function getSubmitLine($label) {
+		$ret = '';
 		
-		$ret[] = '<tr><td class="tdlabel" colspan="'.$this->cols.'" align="center">';
-		$ret = array_merge($ret,$this->getSubmitField($label));
-		$ret[] = '</td></tr>';
+		$ret .= '<tr><td class="tdlabel" colspan="'.$this->cols.'" align="center">';
+		$ret .= $this->getSubmitField($label);
+		$ret .= '</td></tr>';
 		
 		return $ret;
 	}
@@ -197,11 +221,14 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function initForm() {
-		$ret = Array();
+	public function initForm() {
+		$ret = '';
 		
-		$ret[] = '<form name="'.$this->name.'" id="'.$this->id.'" method="'.$this->method.'" action="'.$this->action.'" enctype="'.$this->enctype.'" onsubmit="'.$this->onSubmit.'">';
-		$ret[] = '<table name="mytable" class="mytable" id="table_'.$this->id.'">';
+		$method = ($this->method == '') ? '' : 'method="'.$this->method.'"';
+		$onSubmit = ($this->onSubmit == '') ? '' : 'onsubmit="'.$this->onSubmit.'"';
+		
+		$ret .= '<form name="'.$this->name.'" id="'.$this->id.'" '.$method.' action="'.$this->action.'" enctype="'.$this->enctype.'" '.$onSubmit.'>';
+		$ret .= '<table name="mytable" class="mytable" id="table_'.$this->id.'">';
 		
 		return $ret;
 	}
@@ -212,9 +239,8 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function closeForm() {
-		$ret = Array('</table></form>');
-		return $ret;
+	public function closeForm() {
+		return '</table></form>';
 	}
 	
 	/**
@@ -224,11 +250,8 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getSubmitField($label) {
-		$ret = Array();
-		$ret[] = '<input class="submit" type="submit" name="submit" id="commit" value="'.$label.'" />';
-		
-		return $ret;
+	public function getSubmitField($label) {
+		return '<input class="submit" type="submit" name="submit" id="commit" value="'.$label.'" />';
 	}
 	
 	/**
@@ -241,22 +264,22 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getSelectField($name,$arr,$onChange='',$must=FALSE,$onBlur='') {
-		$ret = Array();
-		$ret[] = '<select name="'.$name.'" onChange="'.$onChange.'" onBlur="'.$onBlur.'">';
+	public function getSelectField($name,$arr,$onChange='',$must=FALSE,$onBlur='') {
+		$ret = '';
+		$ret .= '<select id="'.$name.'" name="'.$name.'" onChange="'.$onChange.'" onBlur="'.$onBlur.'">';
 		
 		if(!$must) {
-			$ret[] = '<option value=""></option>';
+			$ret .= '<option value=""></option>';
 		}
 		
 		foreach($arr AS &$val) {
 			if(is_array($val)) {
-				$ret[] = '<option value="'.$val['value'].'">'.$val['label'].'</option>';
+				$ret .= '<option value="'.$val['value'].'">'.$val['label'].'</option>';
 			} else {
-				$ret[] = '<option value="'.$val.'">'.$val.'</option>';
+				$ret .= '<option value="'.$val.'">'.$val.'</option>';
 			}
 		}
-		$ret[] = '</select>';
+		$ret .= '</select>';
 		
 		return $ret;
 	}
@@ -269,16 +292,22 @@ class GlobalForm {
 	 * @return	Array 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getInputField($name,$value,$onBlur='') {
-		$ret = Array();
+	public function getInputField($name,$value='',$onBlur='') {
+		$ret = '';
 		
-		if(is_array($value)) {
-			$value = implode(',',$value);
-		}
-		
-		$ret[] = '<input type="text" name="'.$name.'" value="'.$value.'" onBlur="'.$onBlur.'" />';
+		$ret .= '<input id="'.$name.'" type="text" name="'.$name.'" value="'.$value.'" onBlur="'.$onBlur.'" />';
 		
 		return $ret;
 	}
+	
+	/**
+	 * Gets the id of the form
+	 *
+	 * @return	Integer  ID of the form
+	 * @author 	Lars Michelsen <lars@vertical-visions.de>
+	 */
+	public function getId() {
+		return $this->id;
+	}
 }
 ?>
\ No newline at end of file
