@@ -26,44 +26,21 @@
  * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class GlobalMap {
-	var $MAINCFG;
-	var $MAPCFG;
+	protected $CORE;
+	protected $MAPCFG;
 	
-	var $linkedMaps = Array();
+	private $linkedMaps = Array();
 	
 	/**
 	 * Class Constructor
 	 *
-	 * @param 	GlobalMainCfg 	$MAINCFG
+	 * @param 	GlobalCore 	$CORE
 	 * @param 	GlobalMapCfg 	$MAPCFG
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function GlobalMap(&$MAINCFG,&$MAPCFG) {
-		$this->MAINCFG = &$MAINCFG;
-		$this->MAPCFG = &$MAPCFG;
-	}
-	
-	/**
-	 * Check if GD-Libs installed, when GD-Libs are enabled
-	 *
-	 * @param	Boolean $printErr
-	 * @return	Boolean	Is Successful?
-	 * @author 	Lars Michelsen <lars@vertical-visions.de>
-	 */
-	function checkGd($printErr) {
-		if($this->MAPCFG->getValue('global', 0, 'usegdlibs') == '1') {
-			if(!extension_loaded('gd')) {
-				if($printErr) {
-					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
-					$FRONTEND->messageToUser('WARNING','gdLibNotFound');
-				}
-				return FALSE;
-			} else {
-				return TRUE;
-			}
-		} else {
-			return TRUE;
-		}
+	public function __construct($CORE,$MAPCFG) {
+		$this->CORE = $CORE;
+		$this->MAPCFG = $MAPCFG;
 	}
 	
 	/**
@@ -71,11 +48,11 @@ class GlobalMap {
 	 *
 	 * @param	String	$src	html path
 	 * @param	String	$style  css parameters
-	 * @return	Array	HTML Code
+	 * @return	String HTML Code
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getBackgroundHtml($src, $style='', $attr='') {
-		return Array('<img id="background" src="'.$src.'" style="z-index:0;'.$style.'" alt="" '.$attr.'>');
+	public function getBackgroundHtml($src, $style='', $attr='') {
+		return '<img id="background" src="'.$src.'" style="z-index:0;'.$style.'" alt="" '.$attr.'>';
 	}
 }
 ?>
