@@ -2,7 +2,7 @@
 /*****************************************************************************
  *
  * NagVisStatefulObject.php - Abstract class of a stateful object in NagVis
- *                  with all necessary informations which belong to the object
+ *                  with all necessary information which belong to the object
  *                  handling in NagVis
  *
  * Copyright (c) 2004-2008 NagVis Project (Contact: lars@vertical-visions.de)
@@ -28,22 +28,30 @@
  * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class NagVisStatefulObject extends NagVisObject {
-	var $MAINCFG;
-	var $BACKEND;
-	var $LANG;
-	var $GRAPHIC;
+	protected $BACKEND;
+	private $GRAPHIC;
 	
 	// "Global" Configuration variables for all stateful objects
-	var $iconset;
+	protected $backend_id;
 	
-	var $label_show;
-	var $recognize_services;
-	var $only_hard_states;
+	protected $iconset;
 	
-	var $iconPath;
-	var $iconHtmlPath;
+	protected $label_show;
+	protected $recognize_services;
+	protected $only_hard_states;
 	
-	var $dateFormat;
+	protected $state;
+	protected $output;
+	protected $summary_state;
+	protected $summary_output;
+	protected $summary_problem_has_been_acknowledged;
+	protected $summary_in_downtime;
+	protected $problem_has_been_acknowledged;
+	
+	protected $iconPath;
+	protected $iconHtmlPath;
+	
+	protected $dateFormat;
 	
 	/**
 	 * Class constructor
@@ -53,26 +61,34 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @param		Object 		Object of class GlobalLanguage
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function NagVisStatefulObject(&$MAINCFG, &$BACKEND, &$LANG) {
-		$this->MAINCFG = &$MAINCFG;
-		$this->BACKEND = &$BACKEND;
-		$this->LANG = &$LANG;
-		
+	public function __construct($CORE, $BACKEND) {
+		$this->BACKEND = $BACKEND;
 		$this->GRAPHIC = '';
 		
-		parent::NagVisObject($this->MAINCFG, $this->LANG);
+		$this->state = '';
+		$this->output = '';
+		$this->problem_has_been_acknowledged = 0;
+		$this->in_downtime = 0;
+		
+		$this->summary_state = '';
+		$this->summary_problem_has_been_acknowledged = 0;
+		$this->summary_in_downtime = 0;
+		
+		parent::__construct($CORE);
 	}
-	
+
 	/**
-	 * PUBLIC getObjectId()
+	 * PUBLIC getStateRelevantMembers
 	 *
-	 * Get method for the object id
+	 * This is a wrapper function. When not implemented by the specific
+	 * object it only calls the getMembers() function. It is useful to
+	 * exclude uninteresting objects on maps.
 	 *
-	 * @return	Integer		Object ID
-	 * @author	Lars Michelsen <lars@vertical-visions.de>
+	 * @return  Array  Array of child objects
+	 * @author  Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getObjectId() {
-		return $this->object_id;
+	public function getStateRelevantMembers() {
+		return $this->getMembers();
 	}
 	
 	/**
@@ -83,7 +99,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	Boolean		True: object is in downtime, False: not in downtime
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getInDowntime() {
+	public function getInDowntime() {
 		return $this->in_downtime;
 	}
 	
@@ -95,7 +111,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		The username of the downtime author
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getDowntimeAuthor() {
+	public function getDowntimeAuthor() {
 		return $this->downtime_author;
 	}
 	
@@ -107,7 +123,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		The downtime data
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getDowntimeData() {
+	public function getDowntimeData() {
 		return $this->downtime_data;
 	}
 	
@@ -119,10 +135,10 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		The formated downtime start time
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getDowntimeStart() {
+	public function getDowntimeStart() {
 		if(isset($this->in_downtime) && $this->in_downtime == 1) {
 			if($this->dateFormat == '') {
-				$this->dateFormat = $this->MAINCFG->getValue('global','dateformat');
+				$this->dateFormat = $this->CORE->MAINCFG->getValue('global','dateformat');
 			}
 			
 			return date($this->dateFormat, $this->downtime_start);
@@ -139,10 +155,10 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		The formated downtime end time
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getDowntimeEnd() {
+	public function getDowntimeEnd() {
 		if(isset($this->in_downtime) && $this->in_downtime == 1) {
 			if($this->dateFormat == '') {
-				$this->dateFormat = $this->MAINCFG->getValue('global','dateformat');
+				$this->dateFormat = $this->CORE->MAINCFG->getValue('global','dateformat');
 			}
 			
 			return date($this->dateFormat, $this->downtime_end);
@@ -159,7 +175,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	Boolean		True: object is in downtime, False: not in downtime
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getSummaryInDowntime() {
+	public function getSummaryInDowntime() {
 		return $this->summary_in_downtime;
 	}
 	
@@ -171,7 +187,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	Boolean		True: Only hard states, False: Not only hard states
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getOnlyHardStates() {
+	public function getOnlyHardStates() {
 		return $this->only_hard_states;
 	}
 	
@@ -183,7 +199,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	Boolean		True: Recognize service states, False: Not recognize service states
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getRecognizeServices() {
+	public function getRecognizeServices() {
 		return $this->recognize_services;
 	}
 	
@@ -195,7 +211,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		State of the object
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getState() {
+	public function getState() {
 		return $this->state;
 	}
 	
@@ -207,7 +223,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		Output of the object
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getOutput() {
+	public function getOutput() {
 		return $this->output;
 	}
 	
@@ -219,8 +235,8 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	Boolean		True: Acknowledged, False: Not Acknowledged
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getAcknowledgement() {
-		return $this->problem_has_been_acknowledged;
+	public function getAcknowledgement() {
+		return (int) $this->problem_has_been_acknowledged;
 	}
 	
 	/**
@@ -231,7 +247,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		Summary state
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getSummaryState() {
+	public function getSummaryState() {
 		return $this->summary_state;
 	}
 	
@@ -243,7 +259,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		Summary output
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getSummaryOutput() {
+	public function getSummaryOutput() {
 		return $this->summary_output;
 	}
 	
@@ -255,8 +271,8 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	Boolean		True: Acknowledged, False: Not Acknowledged
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getSummaryAcknowledgement() {
-		return $this->summary_problem_has_been_acknowledged;
+	public function getSummaryAcknowledgement() {
+		return (int) $this->summary_problem_has_been_acknowledged;
 	}
 	
 	/**
@@ -267,10 +283,10 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		Time in the configured format
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getStateDuration() {
+	public function getStateDuration() {
 		if(isset($this->last_state_change) && $this->last_state_change != '0') {
 			if($this->dateFormat == '') {
-				$this->dateFormat = $this->MAINCFG->getValue('global','dateformat');
+				$this->dateFormat = $this->CORE->MAINCFG->getValue('global','dateformat');
 			}
 			
 			return date($this->dateFormat, ($_SERVER['REQUEST_TIME'] - $this->last_state_change));
@@ -287,10 +303,10 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		Time in the configured format
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getLastStateChange() {
+	public function getLastStateChange() {
 		if(isset($this->last_state_change) && $this->last_state_change != '0') {
 			if($this->dateFormat == '') {
-				$this->dateFormat = $this->MAINCFG->getValue('global','dateformat');
+				$this->dateFormat = $this->CORE->MAINCFG->getValue('global','dateformat');
 			}
 			
 			return date($this->dateFormat, $this->last_state_change);
@@ -307,10 +323,10 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		Time in the configured format
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getLastHardStateChange() {
+	public function getLastHardStateChange() {
 		if(isset($this->last_hard_state_change) && $this->last_hard_state_change != '0') {
 			if($this->dateFormat == '') {
-				$this->dateFormat = $this->MAINCFG->getValue('global','dateformat');
+				$this->dateFormat = $this->CORE->MAINCFG->getValue('global','dateformat');
 			}
 			
 			return date($this->dateFormat, $this->last_hard_state_change);
@@ -327,10 +343,10 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		Time in the configured format
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getLastCheck() {
+	public function getLastCheck() {
 		if(isset($this->last_check) && $this->last_check != '0') {
 			if($this->dateFormat == '') {
-				$this->dateFormat = $this->MAINCFG->getValue('global','dateformat');
+				$this->dateFormat = $this->CORE->MAINCFG->getValue('global','dateformat');
 			}
 			
 			return date($this->dateFormat, $this->last_check);
@@ -347,10 +363,10 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		Time in the configured format
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getNextCheck() {
+	public function getNextCheck() {
 		if(isset($this->next_check) && $this->next_check != '0') {
 			if($this->dateFormat == '') {
-				$this->dateFormat = $this->MAINCFG->getValue('global','dateformat');
+				$this->dateFormat = $this->CORE->MAINCFG->getValue('global','dateformat');
 			}
 			
 			return date($this->dateFormat, $this->next_check);
@@ -367,7 +383,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	String		Type of state (HARD/SOFT)
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getStateType() {
+	public function getStateType() {
 		if(isset($this->state_type) && $this->state_type != '') {
 			$stateTypes = Array(0 => 'SOFT', 1 => 'HARD');
 			return $stateTypes[$this->state_type];
@@ -384,7 +400,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	Integer		Current check attempt
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getCurrentCheckAttempt() {
+	public function getCurrentCheckAttempt() {
 		if(isset($this->current_check_attempt) && $this->current_check_attempt != '') {
 			return $this->current_check_attempt;
 		} else {
@@ -400,7 +416,7 @@ class NagVisStatefulObject extends NagVisObject {
 	 * @return	Integer		maximum check attempts
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function getMaxCheckAttempts() {
+	public function getMaxCheckAttempts() {
 		if(isset($this->max_check_attempts) && $this->max_check_attempts != '') {
 			return $this->max_check_attempts;
 		} else {
@@ -409,236 +425,249 @@ class NagVisStatefulObject extends NagVisObject {
 	}
 	
 	/**
-	 * PUBLIC parse()
+	 * PUBLIC getObjectStateInformations()
 	 *
-	 * Parses the object
+	 * Gets the state information of the object
 	 *
-	 * @return	String		HTML code of the object
-	 * @author	Lars Michelsen <lars@vertical-visions.de>
+	 * @return	Array		Object configuration
+	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function parse() {
-		$this->replaceMacros();
+	public function getObjectStateInformations($bFetchChilds=true) {
+		$arr = Array();
 		
-		// Some specials for lines
-		if(isset($this->line_type)) {
-			$this->getLineHoverArea();
+		/* FIXME: These are no state informations - don't send them
+		if(isset($this->alias) && $this->alias != '') {
+			$arr['alias'] = $this->alias;
+		} else {
+			$arr['alias'] = '';
 		}
 		
-		return $this->parseIcon().$this->parseLabel();
+		if(isset($this->display_name) && $this->display_name != '') {
+			$arr['display_name'] = $this->display_name;
+		} else {
+			$arr['display_name'] = '';
+		}
+		
+		// Save the number of members
+		switch($this->getType()) {
+			case 'host':
+			case 'map':
+			case 'hostgroup':
+			case 'servicegroup':
+				$arr['num_members'] = $this->getNumMembers();
+			break;
+		}*/
+		
+		$arr['state'] = $this->getState();
+		$arr['summary_state'] = $this->getSummaryState();
+		$arr['summary_problem_has_been_acknowledged'] = $this->getSummaryAcknowledgement();
+		$arr['problem_has_been_acknowledged'] = $this->getAcknowledgement();
+		$arr['summary_in_downtime'] = $this->getSummaryInDowntime();
+		$arr['in_downtime'] = $this->getInDowntime();
+		
+		$arr['output'] = strtr($this->output, Array("\r" => '<br />', "\n" => '<br />', '"' => '&quot;', '\'' => '&#145;'));
+		$arr['summary_output'] = strtr($this->getSummaryOutput(), Array("\r" => '<br />', "\n" => '<br />', '"' => '&quot;', '\'' => '&#145;'));
+		
+		// Macros which are only for services and hosts
+		if($this->type == 'host' || $this->type == 'service') {
+			$arr['downtime_author'] = $this->downtime_author;
+			$arr['downtime_data'] = $this->downtime_data;
+			$arr['downtime_end'] = $this->downtime_end;
+			$arr['downtime_start'] = $this->downtime_start;
+			$arr['last_check'] = $this->getLastCheck();
+			$arr['next_check'] = $this->getNextCheck();
+			$arr['state_type'] = $this->getStateType();
+			$arr['current_check_attempt'] = $this->getCurrentCheckAttempt();
+			$arr['max_check_attempts'] = $this->getMaxCheckAttempts();
+			$arr['last_state_change'] = $this->getLastStateChange();
+			$arr['last_hard_state_change'] = $this->getLastHardStateChange();
+			$arr['state_duration'] = $this->getStateDuration();
+			$arr['perfdata'] = strtr($this->perfdata, Array("\r" => '<br />', "\n" => '<br />', '"' => '&quot;', '\'' => '&#145;'));
+		}
+		
+		// Enable/Disable fetching children
+		if($bFetchChilds && $this->getNumMembers() > 0) {
+			$arr['members'] = $this->getSortedObjectMembers();
+		}
+		
+		return $arr;
+	}
+	
+	/**
+	 * PUBLIC parseJson()
+	 *
+	 * Parses the object in json format
+	 *
+	 * @return	String  JSON code of the object
+	 * @author	Lars Michelsen <lars@vertical-visions.de>
+	 */
+	public function parseJson() {
+		// Get the correct url
+		$this->url = $this->getUrl();
+		
+		// When this is a gadget parse the url
+		if($this->view_type == 'gadget') {
+			$this->parseGadgetUrl();
+		}
+		
+		// Get all information of the object (configuration, state, ...)
+		return $this->getObjectInformation();
+	}
+	
+	/**
+	 * PUBLIC fetchIcon()
+	 *
+	 * Fetches the icon for the object depending on the summary state
+	 *
+	 * @author 	Lars Michelsen <lars@vertical-visions.de>
+	 */
+	public function fetchIcon() {
+		// Set the paths of this iconset
+		$this->iconPath = $this->CORE->MAINCFG->getValue('paths', 'icon');
+		$this->iconHtmlPath = $this->CORE->MAINCFG->getValue('paths', 'htmlicon');
+		
+		// Read the filetype of the iconset
+		$fileType = $this->CORE->getIconsetFiletype($this->iconset);
+		
+		if($this->getSummaryState() != '') {
+			$stateLow = strtolower($this->getSummaryState());
+			
+			switch($stateLow) {
+				case 'unknown':
+				case 'unreachable':
+				case 'down':
+					if($this->getSummaryAcknowledgement() == 1) {
+						$icon = $this->iconset.'_ack.'.$fileType;
+					} elseif($this->getSummaryInDowntime() == 1) {
+						$icon = $this->iconset.'_downtime.'.$fileType;
+					} else {
+						// Handle unreachable state with down icon
+						if($stateLow == 'unreachable') {
+							$stateLow = 'down';
+						}
+						$icon = $this->iconset.'_'.$stateLow.'.'.$fileType;
+					}
+				break;
+				case 'critical':
+				case 'warning':
+					if($this->getSummaryAcknowledgement() == 1) {
+						$icon = $this->iconset.'_sack.'.$fileType;
+					} elseif($this->getSummaryInDowntime() == 1) {
+						$icon = $this->iconset.'_sdowntime.'.$fileType;
+					} else {
+						$icon = $this->iconset.'_'.$stateLow.'.'.$fileType;
+					}
+				break;
+				case 'up':
+				case 'ok':
+					if($this->getType() == 'service' || $this->getType() == 'servicegroup') {
+						$icon = $this->iconset.'_ok.'.$fileType;
+					} else {
+						$icon = $this->iconset.'_up.'.$fileType;
+					}
+				break;
+				case 'pending':
+					$icon = $this->iconset.'_'.$stateLow.'.'.$fileType;
+				break;
+				default:
+					$icon = $this->iconset.'_error.'.$fileType;
+				break;
+			}
+			
+			//Checks whether the needed file exists
+			if(@file_exists($this->CORE->MAINCFG->getValue('paths', 'icon').$icon)) {
+				$this->icon = $icon;
+			} else {
+				$this->icon = $this->iconset.'_error.'.$fileType;
+			}
+		} else {
+			$this->icon = $this->iconset.'_error.'.$fileType;
+		}
 	}
 	
 	# End public methods
 	# #########################################################################
 	
 	/**
-	 * Replaces macros of urls and hover_urls
-	 *
-	 * @author 	Lars Michelsen <lars@vertical-visions.de>
-	 */
-	function replaceMacros() {
-		if($this->type == 'service') {
-			$name = 'host_name';
-		} else {
-			$name = $this->type . '_name';
-		}
-		
-		if(isset($this->url) && $this->url != '') {
-			$this->url = str_replace('['.$name.']',$this->$name,$this->url);
-			if($this->type == 'service') {
-				$this->url = str_replace('[service_description]', $this->service_description, $this->url);
-			}
-		}
-		
-		if(isset($this->hover_url) && $this->hover_url != '') {
-			$this->hover_url = str_replace('[name]',$this->$name, $this->hover_url);
-			if($this->type == 'service') {
-				$this->hover_url = str_replace('[service_description]', $this->service_description, $this->hover_url);
-			}
-		}
-		
-		if(isset($this->label_text) && $this->label_text != '') {
-			// For maps use the alias as display string
-			if($this->type == 'map') {
-				$name = 'alias';   
-			}
-			
-			$this->label_text = str_replace('[name]', $this->$name, $this->label_text);
-			$this->label_text = str_replace('[output]',$this->output, $this->label_text);
-			if($this->type == 'service') {
-				$this->label_text = str_replace('[service_description]', $this->service_description, $this->label_text);
-			}
-		}
-		
-		parent::replaceMacros();
-		
-	}
-	
-	/**
-	 * Calculates the position of the line hover area
-	 *
-	 * @author 	Lars Michelsen <lars@vertical-visions.de>
-	 */
-	function getLineHoverArea() {
-		list($xFrom,$xTo) = explode(',', $this->getX());
-		list($yFrom,$yTo) = explode(',', $this->getY());
-		
-		// If the graphic class is not initialized
-		if($this->GRAPHIC == '') {
-			// Initialize the GlobalGraphic class
-			$this->GRAPHIC = new GlobalGraphic();
-		}
-		
-		$this->x = $this->GRAPHIC->middle($xFrom,$xTo) - 10;
-		$this->y = $this->GRAPHIC->middle($yFrom,$yTo) - 10;
-		$this->icon = '20x20.gif';
-	}
-	
-	/**
-	 * Parses the HTML-Code of an icon
-	 *
-	 * @return	String		HTML code of the icon
-	 * @author	Lars Michelsen <lars@vertical-visions.de>
-	 */
-	function parseIcon() {
-		if($this->type == 'service') {
-			$name = 'host_name';
-			$alt = $this->host_name.'-'.$this->service_description;
-		} else {
-			$alt = $this->{$this->type.'_name'};
-		}
-		
-		$ret = '<div class="icon" style="left:'.$this->x.'px;top:'.$this->y.'px;z-index:'.$this->z.';">';
-		$ret .= $this->createLink();
-		$ret .= '<img src="'.$this->iconHtmlPath.$this->icon.'" '.$this->getHoverMenu().' alt="'.$this->type.'-'.$alt.'">';
-		$ret .= '</a>';
-		$ret .= '</div>';
-		
-		return $ret;
-	}
-	
-	/**
-	 * Parses the HTML-Code of a label
-	 *
-	 * @return	String		HTML code of the label
-	 * @author	Lars Michelsen <lars@vertical-visions.de>
-	 */
-	function parseLabel() {
-		if(isset($this->label_show) && $this->label_show == '1') {
-			if($this->type == 'service') {
-				$name = 'host_name';
-			} else {
-				$name = $this->type . '_name';
-			}
-			
-			// If there is a presign it should be relative to the objects x/y
-			if(preg_match('/^(?:\+|\-)/', $this->label_x)) {
-				$this->label_x = $this->x + $this->label_x;
-			}
-			if(preg_match('/^(?:\+|\-)/',$this->label_y)) {
-				$this->label_y = $this->y + $this->label_y;
-			}
-			
-			// If no x/y coords set, fallback to object x/y
-			if(!isset($this->label_x) || $this->label_x == '' || $this->label_x == 0) {
-				$this->label_x = $this->x;
-			}
-			if(!isset($this->label_y) || $this->label_y == '' || $this->label_y == 0) {
-				$this->label_y = $this->y;
-			}
-			
-			if(isset($this->label_width) && $this->label_width != 'auto') {
-				$this->label_width .= 'px';	
-			}
-			
-			/**
-			 * IE workaround: The transparent for the color is not enough. The border
-			 * has really to be hidden.
-			 */
-			if($this->label_border == 'transparent') {
-				$borderStyle = 'border-style:none';
-			} else {
-				$borderStyle = 'border-style:solid';
-			}
-			
-			$ret  = '<div class="object_label" style="background:'.$this->label_background.';'.$borderStyle.';border-color:'.$this->label_border.';left:'.$this->label_x.'px;top:'.$this->label_y.'px;width:'.$this->label_width.';z-index:'.($this->z+1).';overflow:visible;">';
-			$ret .= '<span>'.$this->label_text.'</span>';
-			$ret .= '</div>';
-			
-			return $ret;
-		} else {
-			return '';
-		}
-	}
-	
-	/**
-	 * PRIVATE mergeSummaryOutput()
+	 * RPROTECTED mergeSummaryOutput()
 	 *
 	 * Merges the summary output from objects and all child objects together
 	 *
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function mergeSummaryOutput(&$arrStates, $objLabel) {
-		$this->summary_output .= $this->LANG->getLabel('childStatesAre').' ';
+	protected function mergeSummaryOutput(&$arrStates, $objLabel) {
+		$this->summary_output .= $this->CORE->LANG->getText('childStatesAre').' ';
 		foreach($arrStates AS $state => &$num) {
 			if($num > 0) {
 				$this->summary_output .= $num.' '.$state.', ';
 			}
 		}
 		
-		// Remove last comata
+		// Remove last comma
 		$this->summary_output = preg_replace('/, $/', '', $this->summary_output);
 		
 		$this->summary_output .= ' '.$objLabel.'.';
 	}
 	
 	/**
+	 * PROTECTED wrapChildState()
+	 *
 	 * Wraps the state of the current object with the given child object
 	 *
 	 * @param		Object		Object with a state
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	/**
-	 * Wraps the state of the current object with the given child object
-	 *
-	 * @param		Object		Object with a state
-	 * @author	Lars Michelsen <lars@vertical-visions.de>
-	 */
-	function wrapChildState(&$OBJ) {
-		$arrStates = Array('UNREACHABLE' => 6, 
-							'DOWN' => 5, 
-							'CRITICAL' => 5, 
-							'WARNING' => 4, 
-							'UNKNOWN' => 3, 
-							'ERROR' => 2, 
-							'UP' => 1, 
-							'OK' => 1, 
-							'PENDING' => 0);
-		
+	protected function wrapChildState($OBJ) {
 		$sSummaryState = $this->getSummaryState();
 		$sObjSummaryState = $OBJ->getSummaryState();
-		if($sSummaryState != '') {
-			/* When the state of the current child is not as good as the current
-			 * summary state or the state is equal and the sub-state differs.
-			 */
-			if($arrStates[$sSummaryState] < $arrStates[$sObjSummaryState] || ($arrStates[$sSummaryState] == $arrStates[$sObjSummaryState] && ($this->getSummaryAcknowledgement() || $this->getSummaryInDowntime()))) {
+	
+		$stateWeight = $this->CORE->MAINCFG->getStateWeight();
+		
+		if(isset($stateWeight[$sObjSummaryState])) {
+			if($sSummaryState != '') {
+				/* When the state of the current child is not as good as the current
+				 * summary state or the state is equal and the sub-state differs.
+				 */
+				
+				// Gather the current summary state type
+				$sType = 'normal';
+				if($this->getSummaryAcknowledgement() == 1 && isset($stateWeight[$sSummaryState]['ack'])) {
+					$sType = 'ack';
+				} elseif($this->getSummaryInDowntime() == 1 && isset($stateWeight[$sSummaryState]['downtime'])) {
+					$sType = 'downtime';
+				}
+								
+				// Gather the object summary state type
+				$sObjType = 'normal';
+				if($OBJ->getSummaryAcknowledgement() == 1 && isset($stateWeight[$sObjSummaryState]['ack'])) {
+					$sObjType = 'ack';
+				} elseif($OBJ->getSummaryInDowntime() == 1 && isset($stateWeight[$sObjSummaryState]['downtime'])) {
+					$sObjType = 'downtime';
+				}
+				
+				if($stateWeight[$sSummaryState][$sType] < $stateWeight[$sObjSummaryState][$sObjType]) { 
+					$this->summary_state = $sObjSummaryState;
+					
+					if($OBJ->getSummaryAcknowledgement() == 1) {
+						$this->summary_problem_has_been_acknowledged = 1;
+					} else {
+						$this->summary_problem_has_been_acknowledged = 0;
+					}
+					
+					if($OBJ->getSummaryInDowntime() == 1) {
+						$this->summary_in_downtime = 1;
+					} else {
+						$this->summary_in_downtime = 0;
+					}
+				}
+			} else {
 				$this->summary_state = $sObjSummaryState;
-				
-				if($OBJ->getSummaryAcknowledgement() == 1) {
-					$this->summary_problem_has_been_acknowledged = 1;
-				} else {
-					$this->summary_problem_has_been_acknowledged = 0;
-				}
-				
-				if($OBJ->getSummaryInDowntime() == 1) {
-					$this->summary_in_downtime = 1;
-				} else {
-					$this->summary_in_downtime = 0;
-				}
+				$this->summary_problem_has_been_acknowledged = $OBJ->getSummaryAcknowledgement();
+				$this->summary_in_downtime = $OBJ->getSummaryInDowntime();
 			}
 		} else {
-			$this->summary_state = $sObjSummaryState;
-			$this->summary_problem_has_been_acknowledged = $OBJ->getSummaryAcknowledgement();
-			$this->summary_in_downtime = $OBJ->getSummaryInDowntime();
+			//FIXME: Error no valid state
+			echo $OBJ->getName().": Unkown state: ".$sObjSummaryState;
 		}
 	}
 }
