@@ -26,8 +26,8 @@
  * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class WuiBackground extends GlobalBackground {
-	function WuiBackground(&$MAINCFG, $image) {
-		parent::GlobalBackground($MAINCFG, $image);
+	function __construct($CORE, $image) {
+		parent::__construct($CORE, $image);
 	}
 	
 	/**
@@ -39,17 +39,18 @@ class WuiBackground extends GlobalBackground {
 	*/
 	function deleteImage($printErr=1) {
 		if($this->checkFolderWriteable($printErr) && $this->checkFileWriteable($printErr)) {
-			if(unlink($this->MAINCFG->getValue('paths', 'map').$this->image)) {
+			if(unlink($this->CORE->MAINCFG->getValue('paths', 'map').$this->image)) {
 				return TRUE;
 			} else {
-				$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
-				$FRONTEND->messageToUser('ERROR','couldNotDeleteMapImage','IMGPATH~'.$this->MAINCFG->getValue('paths', 'map').$this->image);
+				if($printErr) {
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('couldNotDeleteMapImage','IMGPATH~'.$this->CORE->MAINCFG->getValue('paths', 'map').$this->image));
+				}
 				return FALSE;
 			}
 		}
 	}
 	
-	/**
+	/**                                
 	* Uploads a map image
 	*
 	* @param	Boolean	$printErr
@@ -59,17 +60,17 @@ class WuiBackground extends GlobalBackground {
 	function uploadImage($arr, $printErr=1) {
 		if(is_uploaded_file($arr['tmp_name'])) {
 			$fileName = $arr['name'];
-			if(preg_match('/\.png/i',$fileName)) {
+			if(preg_match(MATCH_PNG_GIF_JPG_FILE,$fileName)) {
 				if($this->checkFolderWriteable(1)) {
-					if(move_uploaded_file($arr['tmp_name'], $this->MAINCFG->getValue('paths', 'map').$fileName)) {
+					if(move_uploaded_file($arr['tmp_name'], $this->CORE->MAINCFG->getValue('paths', 'map').$fileName)) {
 						// Change permissions of the map image
-						chmod($this->MAINCFG->getValue('paths', 'map').$fileName,0666);
+						chmod($this->CORE->MAINCFG->getValue('paths', 'map').$fileName,0666);
 						
 						return TRUE;
 					} else {
-						// Error handling
-						$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:backgroundManagement'));
-						$FRONTEND->messageToUser('ERROR','moveUploadedFileFailed');
+						if($printErr) {
+							new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('moveUploadedFileFailed'));
+						}
 						return FALSE;
 					}
 				} else {
@@ -77,15 +78,15 @@ class WuiBackground extends GlobalBackground {
 					return FALSE;
 				}
 			} else {
-				// Error handling
-				$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:backgroundManagement'));
-				$FRONTEND->messageToUser('ERROR','mustBePngFile');
+				if($printErr) {
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('mustChooseValidImageFormat'));
+				}
 				return FALSE;
 			}
 		} else {
-			// Error handling
-			$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:backgroundManagement'));
-			$FRONTEND->messageToUser('ERROR','fileCouldNotBeUploaded');
+			if($printErr) {
+				new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('fileCouldNotBeUploaded'));
+			}
 			return FALSE;
 		}
 	}
@@ -111,7 +112,7 @@ class WuiBackground extends GlobalBackground {
 				
 				$bgColor = imagecolorallocate($image, $r, $g, $b);
 				imagefill($image, 0, 0, $bgColor);
-				imagepng($image,$this->MAINCFG->getValue('paths', 'map').$this->image);
+				imagepng($image,$this->CORE->MAINCFG->getValue('paths', 'map').$this->image);
 				imagedestroy($image);
 				
 				return TRUE;
@@ -120,11 +121,11 @@ class WuiBackground extends GlobalBackground {
 				return FALSE;
 			}
 		} else {
-			// Error handling
-			$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:backgroundManagement'));
-			$FRONTEND->messageToUser('ERROR','imageAlreadyExists','IMAGE~'.$this->MAINCFG->getValue('paths', 'map').$this->image);
+			if($printErr) {
+				new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('imageAlreadyExists','IMAGE~'.$this->CORE->MAINCFG->getValue('paths', 'map').$this->image));
+			}
 			return FALSE;
 		}
 	}
 }
-?>
\ No newline at end of file
+?>
