@@ -26,9 +26,7 @@
  * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class WuiFrontend extends GlobalPage {
-	var $MAINCFG;
 	var $MAPCFG;
-	var $LANG;
 	
 	var $MAP;
 	
@@ -37,24 +35,35 @@ class WuiFrontend extends GlobalPage {
 	*
 	* @author Lars Michelsen <lars@vertical-visions.de>
 	*/
-	function WuiFrontend(&$MAINCFG,&$MAPCFG) {
-		$this->MAINCFG = &$MAINCFG;
-		$this->MAPCFG = &$MAPCFG;
+	function WuiFrontend($CORE, $MAPCFG) {
+		$this->MAPCFG = $MAPCFG;
 		
-		$this->LANG = new GlobalLanguage($this->MAINCFG,'wui:global');
-		
-		$prop = Array('title'=>$MAINCFG->getValue('internal', 'title'),
-					  'cssIncludes'=>Array('../nagvis/includes/css/style.css','./includes/css/wui.css','./includes/css/office_xp/office_xp.css'),
-					  'jsIncludes'=>Array('../nagvis/includes/js/ajax.js','./includes/js/wui.js',
-					  	  './includes/js/ajax.js',
+		$prop = Array('title'=> $CORE->MAINCFG->getValue('internal', 'title') . 'WUI',
+					  'cssIncludes'=>Array('../nagvis/includes/css/style.css',
+						                     './includes/css/wui.css',
+						                     './includes/css/office_xp/office_xp.css'),
+					  'jsIncludes'=>Array(
+							'../nagvis/includes/js/frontendEventlog.js',
+							'../nagvis/includes/js/ajax.js',
+							'../nagvis/includes/js/frontendMessage.js',
+							'../nagvis/includes/js/nagvis.js',
+					  	'./includes/js/popupWindow.js',
+							'./includes/js/wui.js',
+					  	'./includes/js/ajax.js',
+					  	'./includes/js/addmodify.js',
+					  	'./includes/js/EditMainCfg.js',
+					  	'./includes/js/BackgroundManagement.js',
+					  	'./includes/js/BackendManagement.js',
+					  	'./includes/js/MapManagement.js',
+					  	'./includes/js/ShapeManagement.js',
 						  './includes/js/jsdomenu.js',
 						  './includes/js/jsdomenu.inc.js',
 						  './includes/js/wz_jsgraphics.js',
 						  './includes/js/wz_dragdrop.js'),
-					  'extHeader'=>Array("<style type=\"text/css\">body.main { background-color: ".$this->MAPCFG->getValue('global',0, 'background_color')."; }</style>"),
-					  'allowedUsers' => $this->MAPCFG->getValue('global', 0,'allowed_for_config'),
-					  'languageRoot' => 'wui:global');
-		parent::GlobalPage($this->MAINCFG,$prop);
+					  'extHeader'=> '<style type="text/css">body.main { background-color: '.$this->MAPCFG->getValue('global',0, 'background_color').'; }</style>',
+					  'allowedUsers' => $this->MAPCFG->getValue('global', 0, 'allowed_for_config'),
+					  'languageRoot' => 'nagvis');
+		parent::__construct($CORE, $prop);
 	}
 	
 	function checkPreflight() {
@@ -66,8 +75,7 @@ class WuiFrontend extends GlobalPage {
 	function checkPHPMBString($printErr=1) {
 		if (!extension_loaded('mbstring')) {
 			if($printErr) {
-				$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
-				$FRONTEND->messageToUser('ERROR','phpModuleNotLoaded','MODULE~mbstring');
+				new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('phpModuleNotLoaded','MODULE~mbstring'));
 			}
 			return FALSE;
 		} else {
@@ -82,18 +90,9 @@ class WuiFrontend extends GlobalPage {
 	*/
 	function getMap() {
 		$this->addBodyLines('<div id="mymap" class="map">');
-		$this->MAP = new WuiMap($this->MAINCFG,$this->MAPCFG,$this->LANG);
+		$this->MAP = new WuiMap($this->CORE, $this->MAPCFG);
 		$this->addBodyLines($this->MAP->parseMap());
 		$this->addBodyLines('</div>');
 	}
-	
-	/**
-	 * Adds the user messages to the page
-	 *
-	 * @author	Lars Michelsen <lars@vertical-visions.de>
-	 */
-	function getMessages() {
-		$this->addBodyLines($this->getUserMessages());	
-	}
 }
 ?>
