@@ -26,10 +26,10 @@
  * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class WuiMap extends GlobalMap {
+	var $CORE;
 	var $MAINCFG;
 	var $MAPCFG;
 	var $LANG;
-	var $GRAPHIC;
 	
 	var $objects;
 	var $moveable;
@@ -38,18 +38,18 @@ class WuiMap extends GlobalMap {
 	/**
 	 * Class Constructor
 	 *
-	 * @param 	$MAINCFG WuiMainCfg
+	 * @param 	$CORE WuiMainCfg
 	 * @param 	$MAPCFG  GlobalMapCfg
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function WuiMap(&$MAINCFG,&$MAPCFG,&$LANG) {
-		$this->MAINCFG = &$MAINCFG;
+	function WuiMap(&$CORE, &$MAPCFG) {
+		$this->CORE = &$CORE;
+		$this->MAINCFG = &$CORE->MAINCFG;
+		$this->LANG = &$CORE->LANG;
+		
 		$this->MAPCFG = &$MAPCFG;
-		$this->LANG = &$LANG;
 		
-		$this->GRAPHIC = new GlobalGraphic();
-		
-		parent::GlobalMap($MAINCFG,$MAPCFG);
+		parent::__construct($CORE, $MAPCFG);
 		
 		$this->loadPermissions();
 		$this->objects = $this->getMapObjects(1);
@@ -61,74 +61,51 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function loadPermissions() {
-		$mapOptions = '[ ';
-		$a = 0;
-		foreach($this->getMaps() AS $map) {
-			if($a > 0) {
-				$mapOptions .= ', ';	
-			}
+		$aArr = Array();
+		foreach($this->CORE->getAvailableMaps('/[^(__automap)]/') AS $map) {
+			$aOpts = Array();
 			
-			$MAPCFG1 = new WuiMapCfg($this->MAINCFG,$map);
+			$MAPCFG1 = new WuiMapCfg($this->CORE, $map);
 			$MAPCFG1->readMapConfig(0);
-			$mapOptions .= '{ mapName:\''.$map.'\'';
+			
+			$aOpts['mapName'] = $map;
 			
 			// map alias
-			$mapOptions .= ', mapAlias:\''.$MAPCFG1->getValue('global', '0', 'alias').'\'';
+			$aOpts['mapAlias'] = $MAPCFG1->getValue('global', '0', 'alias');
 			
 			// used image
-			$mapOptions .= ', mapImage:\''.$MAPCFG1->getValue('global', '0', 'map_image').'\'';
+			$aOpts['mapImage'] = $MAPCFG1->getValue('global', '0', 'map_image');
 			
 			// permited users for writing
-			$mapOptions .= ', allowedForConfig:[ ';
+			$aOpts['allowedForConfig'] = Array();
 			$arr = $MAPCFG1->getValue('global', '0', 'allowed_for_config');
 			for($i = 0; count($arr) > $i; $i++) {
-				if($i > 0) {
-					$mapOptions .= ',';	
-				}
-				$mapOptions .= '\''.$arr[$i].'\' ';
+				$aOpts['allowedForConfig'][] = $arr[$i];
 			}
-			$mapOptions .= ' ]';
 			
 			// permited users for viewing the map
-			$mapOptions .= ', allowedUsers:[ ';
+			$aOpts['allowedUsers'] = Array();
 			$arr = $MAPCFG1->getValue('global', '0', 'allowed_user');
 			for($i = 0; count($arr) > $i; $i++) {
-				if($i > 0) {
-					$mapOptions .= ',';	
-				}
-				$mapOptions .= '\''.$arr[$i].'\' ';
+				$aOpts['allowedUsers'][] = $arr[$i];
 			}
-			$mapOptions .= ' ]';
 			
 			// linked maps
-			$mapOptions .= ', linkedMaps:[ ';
-			$i = 0;
+			$aOpts['linkedMaps'] = Array();
 			foreach($MAPCFG1->getDefinitions('map') AS $key => $obj) {
-				if($i > 0) {
-					$mapOptions .= ',';
-				}
-				$mapOptions .= '\''.$obj['map_name'].'\' ';
-				$i++;
+				$aOpts['allowedUsers'][] = $obj['map_name'];
 			}
-			$mapOptions .= ' ]';
 
 			// used shapes
-			$mapOptions .= ', usedShapes:[ ';
-			$i = 0;
+			$aOpts['usedShapes'] = Array();
 			foreach($MAPCFG1->getDefinitions('shape') AS $key => $obj) {
-				if($i > 0) {
-					$mapOptions .= ',';
-				}
-				$mapOptions .= '\''.$obj['icon'].'\' ';
-				$i++;
+				$aOpts['usedShapes'][] = $obj['icon'];
 			}
-			$mapOptions .= ' ]';
 			
-			$mapOptions .= ' }';
-			$a++;
+			$aArr[] = $aOpts;
 		}
-		$mapOptions .= ' ]';
-		$this->MAINCFG->setRuntimeValue('mapOptions',$mapOptions);
+		
+		$this->MAINCFG->setRuntimeValue('mapOptions', json_encode($aArr));
 	}
 	
 	/**
@@ -138,13 +115,13 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function parseMap() {
-		$ret = Array();
-		$ret = array_merge($ret,$this->getBackground());
-		$ret = array_merge($ret,$this->parseJs($this->getJsGraphicObj()."\n".$this->getJsLang()."\n".$this->getJsValidMainConfig()."\n".$this->getJsValidMapConfig()));
-		$ret = array_merge($ret,$this->parseObjects());
-		$ret = array_merge($ret,$this->parseInvisible());
-		$ret = array_merge($ret,$this->makeObjectsMoveable());
-		$ret = array_merge($ret,Array("<script type=\"text/javascript\" src=\"./includes/js/wz_tooltip.js\"></script>"));
+		$ret = '';
+		$ret .= $this->getBackground();
+		$ret .= $this->parseJs($this->getJsGraphicObj()."\n".$this->getJsLang()."\n".$this->getJsValidMainConfig()."\n".$this->getJsValidMapConfig());
+		$ret .= $this->parseObjects();
+		$ret .= $this->parseInvisible();
+		$ret .= $this->makeObjectsMoveable();
+		$ret .= '<script type="text/javascript" src="./includes/js/wz_tooltip.js"></script>';
 		
 		return $ret;
 	}
@@ -157,14 +134,23 @@ class WuiMap extends GlobalMap {
      */
 	function getBackground() {
 		$style = '';
+		$src = '';
+		$sRet = '';
+		
 		if($this->MAPCFG->getName() != '') {
-			$src = $this->MAINCFG->getValue('paths', 'htmlmap').$this->MAPCFG->BACKGROUND->getFileName();
+			if($this->MAPCFG->BACKGROUND->getFileName() != 'none' && $this->MAPCFG->BACKGROUND->getFileName() != '') {
+				$src = $this->MAINCFG->getValue('paths', 'htmlmap').$this->MAPCFG->BACKGROUND->getFileName();
+			}
 		} else {
 			$src = './images/internal/wuilogo.png';
 			$style = 'width:800px; height:600px;';
 		}
 		
-		return $this->getBackgroundHtml($src, $style);
+		if($src != '') {
+			$sRet = $this->getBackgroundHtml($src, $style);
+		}
+		
+		return $sRet;
 	}
 	
 	/**
@@ -189,10 +175,10 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function makeObjectsMoveable() {
-		$ret = Array();
+		$ret = '';
 		
 		if(strlen($this->moveable) != 0) {
-			$ret = $this->parseJs("SET_DHTML(TRANSPARENT,CURSOR_HAND,".substr($this->moveable,0,strlen($this->moveable)-1).");\n");
+			$ret = $this->parseJs("SET_DHTML(SCROLL,NO_ALT,TRANSPARENT,CURSOR_HAND,".substr($this->moveable, 0, strlen($this->moveable) - 1).");\n");
 		}
 		
 		return $ret;
@@ -202,51 +188,55 @@ class WuiMap extends GlobalMap {
 	 * Parses given Js code
 	 *
 	 * @param	String	$js	Javascript code to parse
-	 * @return	Array 	Html
+	 * @return	String 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function parseJs($js) {
-		$ret = Array();
+		$ret = '';
 		
-		$ret[] = "<script type=\"text/javascript\" language=\"JavaScript\">";
-		$ret[] = "<!--";
+		$ret .= "<script type=\"text/javascript\">";
 		if(is_array($js)) {
-			$ret = array_merge($ret,$js);
+			$ret .= implode("\n",$js);
 		} else {
-			$ret[] = $js;
+			$ret .= $js;
 		}
-		$ret[] = "//-->";
-		$ret[] = "</script>";
+		$ret .= "</script>";
 		
 		return $ret;
 	}
 	
+	function middle($x1,$x2) {
+		$ret = ($x1+($x2-$x1)/2);
+		return $ret;
+	}
+	
 	/**
 	 * Parses all objects on the map
 	 *
-	 * @return	Array 	Html
+	 * @return	String 	Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function parseObjects() {
-		$ret = Array();
+		$ret = '';
 		
 		foreach($this->objects AS $var => $obj) {
 			switch($obj['type']) {
 				case 'textbox':
 					$obj['class'] = "box";
 					$obj['icon'] = "20x20.gif";
+					$obj['iconParams'] = '';
 					
-					$ret = array_merge($ret,$this->textBox($obj));
+					$ret .= $this->textBox($obj);
 					$obj = $this->fixIcon($obj);
-					$ret = array_merge($ret,$this->parseIcon($obj));
+					$ret .= $this->parseIcon($obj);
 				break;
 				default:
 					if(isset($obj['line_type'])) {
 						list($pointa_x,$pointb_x) = explode(",", $obj['x']);
 						list($pointa_y,$pointb_y) = explode(",", $obj['y']);
-						$ret[] = "<script type=\"text/javascript\">myshape_background.drawLine(".$pointa_x.",".$pointa_y.",".$pointb_x.",".$pointb_y.");</script>";
-						$obj['x'] = $this->GRAPHIC->middle($pointa_x,$pointb_x) - 10;
-						$obj['y'] = $this->GRAPHIC->middle($pointa_y,$pointb_y) - 10;
+						$ret .= "<script type=\"text/javascript\">myshape_background.drawLine(".$pointa_x.",".$pointa_y.",".$pointb_x.",".$pointb_y.");</script>";
+						$obj['x'] = round(($pointa_x+($pointb_x-$pointa_x)/2) - 10);
+						$obj['y'] = round(($pointa_y+($pointb_y-$pointa_y)/2) - 10);
 						
 						$obj['icon'] = '20x20.gif';
 					} else {
@@ -256,11 +246,29 @@ class WuiMap extends GlobalMap {
 						}
 					}
 					
+					if(isset($obj['view_type']) && $obj['view_type'] == 'gadget') {
+						$sDelim = '&';
+						
+						// If there is no ? use the ? as start for the params list
+						if(strpos($obj['gadget_url'], '?') === false) {
+							$sDelim = '?';
+						}
+
+						$sGadgetOpts = '';
+						if(isset($obj['gadget_opts']) && $obj['gadget_opts'] != '') {
+							$sGadgetOpts = '&opts=' . urlencode($obj['gadget_opts']);
+						}
+						
+						$obj['iconParams'] = $sDelim . 'name1=dummyHost&name2=dummyService&state=OK&stateType=HARD&conf=1&scale=' . $obj['gadget_scale'] . $sGadgetOpts;
+					} else {
+						$obj['iconParams'] = '';
+					}
+					
 					$obj = $this->fixIcon($obj);
-					$ret = array_merge($ret,$this->parseIcon($obj));
+					$ret .= $this->parseIcon($obj);
 					
 					if(isset($obj['label_show']) && $obj['label_show'] == '1') {
-						$ret[] = $this->parseLabel($obj);
+						$ret .= $this->parseLabel($obj);
 					}
 				break;	
 			}
@@ -281,6 +289,18 @@ class WuiMap extends GlobalMap {
 		
 		if($obj['type'] == 'shape' && preg_match('/^\[(.*)\]$/',$obj['icon'],$match) > 0) {
 			$obj['icon'] = $match[1];
+		} elseif(isset($obj['view_type']) && $obj['view_type'] == 'gadget') {
+			if(preg_match('/^\[(.*)\]$/', $obj['gadget_url'], $match) > 0) {
+				$obj['icon'] = $match[1];
+			} else {
+				$obj['icon'] = $obj['gadget_url'];
+				
+				if(!isset($obj['path']) || $obj['path'] == '') {
+					$imgPath = $obj['icon'];
+				} else {
+					$imgPath = $obj['path'].$obj['icon'];
+				}
+			}
 		} else {
 			if(!isset($obj['path']) || $obj['path'] == '') {
 				$imgPath = $obj['icon'];
@@ -289,8 +309,7 @@ class WuiMap extends GlobalMap {
 			}
 			
 			if(!file_exists($imgPath)) {
-				$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
-				$FRONTEND->messageToUser('WARNING','iconNotExists','IMGPATH~'.$imgPath);
+				new GlobalFrontendMessage('WARNING', $this->CORE->LANG->getText('iconNotExists','IMGPATH~'.$imgPath));
 				
 				$obj['path'] = $this->MAINCFG->getValue('paths', 'icon');
 				$obj['htmlPath'] = $this->MAINCFG->getValue('paths', 'htmlicon');
@@ -317,6 +336,14 @@ class WuiMap extends GlobalMap {
 				$obj['path'] = $this->MAINCFG->getValue('paths', 'shape');
 				$obj['htmlPath'] = $this->MAINCFG->getValue('paths', 'htmlshape');
 			}
+		} elseif(isset($obj['view_type']) && $obj['view_type'] == 'gadget') {
+			if(preg_match('/^\[(.*)\]$/', $obj['gadget_url'], $match) > 0) {
+				$obj['path'] = '';
+				$obj['htmlPath'] = '';
+			} else {
+				$obj['path'] = $this->MAINCFG->getValue('paths', 'gadget');
+				$obj['htmlPath'] = $this->MAINCFG->getValue('paths', 'htmlgadgets');
+			}
 		} else {
 			$obj['path'] = $this->MAINCFG->getValue('paths', 'icon');
 			$obj['htmlPath'] = $this->MAINCFG->getValue('paths', 'htmlicon');
@@ -328,10 +355,11 @@ class WuiMap extends GlobalMap {
 	 * Parses the HTML-Code of an icon
 	 *
 	 * @param	Array	$obj	Array with object informations
+	 * @return	String HTML Code
 	 * @author Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function parseIcon(&$obj) {
-		$ret = Array();
+		$ret = '';
 				
 		if($obj['type'] == 'service') {
 			$name = 'host_name';
@@ -339,9 +367,9 @@ class WuiMap extends GlobalMap {
 			$name = $obj['type'] . '_name';
 		}
 		
-		$ret[] = "<div id=\"box_".$obj['type']."_".$obj['id']."\" class=\"icon\" style=\"left:".$obj['x']."px; top:".$obj['y']."px;z-index:".$obj['z']."\">";
-		$ret[] = "\t\t<img src=\"".$obj['htmlPath'].$obj['icon']."\" alt=\"".$obj['type']."_".$obj['id']."\" ".$this->infoBox($obj).">";
-		$ret[] = "</div>";
+		$ret .= "<div id=\"box_".$obj['type']."_".$obj['id']."\" class=\"icon\" style=\"left:".$obj['x']."px; top:".$obj['y']."px;z-index:".$obj['z']."\">";
+		$ret .= "\t\t<img src=\"".$obj['htmlPath'].$obj['icon'].$obj['iconParams']."\" alt=\"".$obj['type']."_".$obj['id']."\" ".$this->infoBox($obj).">";
+		$ret .= "</div>";
 		
 		return $ret;
 	}
@@ -357,7 +385,6 @@ class WuiMap extends GlobalMap {
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function parseLabel(&$obj) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMap::parseLabel(&$obj)');
 		$relative = 0;
 		
 		if($obj['type'] == 'service') {
@@ -390,16 +417,17 @@ class WuiMap extends GlobalMap {
 		
 		//
 		if($relative == 1) {
-			$id = '"id="rel_label_'.$obj['type'].'_'.$obj['id'].'"';
+			$id = 'id="rel_label_'.$obj['type'].'_'.$obj['id'].'"';
+			$this->moveable .= '"rel_label_'.$obj['type'].'_'.$obj['id'].'",';
 		} else {
-			$id = '"id="abs_label_'.$obj['type'].'_'.$obj['id'].'"';
+			$id = 'id="abs_label_'.$obj['type'].'_'.$obj['id'].'"';
+			$this->moveable .= '"abs_label_'.$obj['type'].'_'.$obj['id'].'",';
 		}
 		
 		$ret  = '<div '.$id.' class="object_label" style="background:'.$obj['label_background'].';border-color:'.$obj['label_border'].';left:'.$obj['label_x'].'px;top:'.$obj['label_y'].'px;width:'.$obj['label_width'].';z-index:'.($obj['z']+1).';overflow:visible;">';
 		$ret .= '<span>'.$obj['label_text'].'</span>';
 		$ret .= '</div>';
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMap::parseLabel(): HTML String');
 		return $ret;
 	}
 	
@@ -450,10 +478,8 @@ class WuiMap extends GlobalMap {
 				
 				if($mergeWithGlobals) {
 					// merge with "global" settings
-					foreach($this->MAPCFG->validConfig[$type] AS $key => $values) {
-						if((!isset($obj[$key]) || $obj[$key] == '') && isset($values['default'])) {
-							$obj[$key] = $values['default'];
-						}
+					foreach($this->MAPCFG->getValidTypeKeys($type) AS $key) {
+						$obj[$key] = $this->MAPCFG->getValue($type, $index, $key);
 					}
 				}
 				
@@ -481,36 +507,34 @@ class WuiMap extends GlobalMap {
 	 * @author Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getIcon(&$obj) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::getIcon(&$obj)');
+		$fileType = $this->CORE->getIconsetFiletype($obj['iconset']);
 		
 		switch($obj['type']) {
 			case 'service':
 			case 'servicegroup':
-				$icon = $obj['iconset'].'_ok.png';
+				$icon = $obj['iconset'].'_ok.'.$fileType;
 			break;
 			default:
-					$icon = $obj['iconset'].'_up.png';
+					$icon = $obj['iconset'].'_up.'.$fileType;
 			break;
 		}
 		
 		//replaced: if(file_exists($this->MAINCFG->getValue('paths', 'icon').$icon)) {
 		if(@fclose(@fopen($this->MAINCFG->getValue('paths', 'icon').$icon,'r'))) {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::getIcon(): '.$icon);
 			return $icon;
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::getIcon(): '.$obj['iconset'].'_error.png');
-			return $obj['iconset'].'_error.png';
+			return $obj['iconset'].'_error.'.$fileType;
 		}
 	}
 	
 	/**
 	 * Create a Comment-Textbox
 	 *
-	 * @param	Array	$obj	Array with object informations
+	 * @param	String HTML Code
 	 * @author Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function textBox(&$obj) {
-		$ret = Array();
+		$ret = '';
 		
 		if(isset($obj['w'])) {
 			$obj['w'] = $obj['w'].'px';
@@ -518,9 +542,21 @@ class WuiMap extends GlobalMap {
 			$obj['w'] = 'auto';
 		}
 		
-		$ret[] = "<div class=\"".$obj['class']."\" style=\"left: ".$obj['x']."px; top: ".$obj['y']."px; width: ".$obj['w']."; overflow: visible;\">";	
-		$ret[] = "\t<span>".$obj['text']."</span>";
-		$ret[] = "</div>";
+		if(isset($obj['background_color'])) {
+			$sBgColor = $obj['background_color'];
+		} else {
+			$sBgColor = 'transparent';
+		}
+		
+		if(isset($obj['border_color'])) {
+			$sBorderColor = $obj['border_color'];
+		} else {
+			$sBorderColor = 'border_color';
+		}
+		
+		$ret .= "<div class=\"".$obj['class']."\" style=\"border-color:".$sBorderColor.";background-color:".$sBgColor.";left: ".$obj['x']."px; top: ".$obj['y']."px; z-index: ".$obj['z']."; width: ".$obj['w']."; overflow: visible;\">";	
+		$ret .= "\t<span>".$obj['text']."</span>";
+		$ret .= "</div>";
 		
 		return $ret;	
 	}
@@ -547,60 +583,77 @@ class WuiMap extends GlobalMap {
 		$defaultText = '';
 		
 		// Get configured/inherited variables
-		foreach($this->MAPCFG->validConfig[$obj['type']] AS $key => $values) {
-			$getValue = $this->MAPCFG->getValue($obj['type'],$obj['id'],$key,TRUE);
-			if($key != 'type' && isset($getValue) && $getValue != '') {
-				$configuredText .= '<tr><td>'.$key.'</td><td>'.$getValue.'</td></tr>';
-			} elseif(isset($values['default'])) {
-				$defaultText .= '<tr class=\\\'inherited\\\'><td>'.$key.'</td><td>'.$values['default'].'</td></tr>';
-			}
-		}
-		
-		// Print configured settings
-		$tooltipText .= '<tr><th colspan=\\\'2\\\'>'.$this->LANG->getLabel('configured').'</th></tr>'.$configuredText;
-		// Print inherited settings
-		$tooltipText .= '<tr class=\\\'inherited\\\'><th colspan=\\\'2\\\'>'.$this->LANG->getLabel('inherited').'</th></tr>'.$defaultText;
-		
-		// lines and textboxes have one more link in the tooltip: "size/position"	
-		if(isset($obj['line_type']) || $obj['type']=='textbox') {
-			$positionSizeText = "<a href=javascript:objid=".$obj['id'].";get_click(\'".$obj['type']."\',2,\'modify\');>".$this->LANG->getLabel('positionSize')."</a>";			
-		} else {
-			$positionSizeText = '';	
-		}
-		
-		$tooltipText .= "<tr><th><a href=\'./index.php?page=addmodify&amp;action=modify&amp;map=".$this->MAPCFG->getName()."&amp;type=".$obj['type']."&amp;id=".$obj['id']."\' onclick=\'open_window(href); return false;\'>".$this->LANG->getLabel('change')."</a>&nbsp;".$positionSizeText."</th>";
-		$tooltipText .= "<th><a href=\'./form_handler.php?myaction=delete&amp;map=".$this->MAPCFG->getName()."&amp;type=".$obj['type']."&amp;id=".$obj['id']."\' onClick=\'return confirm_object_deletion();return false;\'>".$this->LANG->getLabel('delete')."</a></th></tr>";
-		
-		$tooltipText.='</table>';
-		
-		$info = "onmouseover=\"this.T_DELAY=1000;this.T_STICKY=true;this.T_OFFSETX=6;this.T_OFFSETY=6;this.T_WIDTH=200;this.T_FONTCOLOR='#000000';this.T_BORDERCOLOR='#000000';this.T_BGCOLOR='#FFFFFF';this.T_STATIC=true;this.T_TITLE='<b>".$this->LANG->getLabel($obj['type'])."</b>';return escape('".$tooltipText."');\"";
-		
-		return $info;
-	}
-	
-	/**
-	 * Gets all defined maps
-	 *
-	 * @return	Array maps
-	 * @author Lars Michelsen <lars@vertical-visions.de>
-     */
-	function getMaps() {
-		$files = Array();
-		
-		if ($handle = opendir($this->MAINCFG->getValue('paths', 'mapcfg'))) {
- 			while (false !== ($file = readdir($handle))) {
-				if(preg_match('/^.+\.cfg$/', $file) && $file != '__automap.cfg') {
-					$files[] = substr($file,0,strlen($file)-4);
-				}				
+		foreach($this->MAPCFG->getValidTypeKeys($obj['type']) AS $key) {
+			$bGlobal = FALSE;
+			$value = $this->MAPCFG->getValue($obj['type'], $obj['id'], $key, TRUE);
+			
+			// Get global value when nothing set
+			if($value == FALSE) {
+				$bGlobal = TRUE;
+				$value = $this->MAPCFG->getValue($obj['type'], $obj['id'], $key, FALSE);
 			}
 			
-			if ($files) {
-				natcasesort($files);
+			// Cleanup some bad signs
+			$value = str_replace('\"','&quot;', $value);
+			$value = str_replace('"','&quot;', $value);
+			
+			if($bGlobal) {
+				$defaultText .= '<tr class=\\\'inherited\\\'><td>'.$key.'</td><td>'.$value.'</td></tr>';
+			} else {
+				$configuredText .= '<tr><td>'.$key.'</td><td>'.$value.'</td></tr>';
 			}
 		}
-		closedir($handle);
 		
-		return $files;
+		/*
+		 * Add action links
+		 */
+		
+		$tooltipText .= "<tr><th colspan=\'2\' style=\'height:34px;\'>";
+		$tooltipText .= "<ul class=\'nav\'>";
+		
+		// Edit link
+		$tooltipText .= "<li><a style=\'background-image:url(".$this->CORE->MAINCFG->getValue('paths','htmlbase')."/wui/images/internal/modify.png)\'"
+		  ." href=# onclick=popupWindow(\'".$this->LANG->getText('change')."\',"
+			."getSyncRequest(\'./ajax_handler.php?action=getFormContents&form=addmodify&do=modify&map=".$this->MAPCFG->getName()."&type=".$obj['type']."&id=".$obj['id']."\',true,false));>"
+			."<span>".$this->LANG->getText('change')."</span></a></li>";
+		
+		// Position/Size link on textboxes/lines
+		//$tooltipText .= "&nbsp;".$positionSizeText;
+		if(isset($obj['line_type']) || $obj['type']=='textbox') {
+			$tooltipText .= "<li><a style=\'background-image:url(".$this->CORE->MAINCFG->getValue('paths','htmlbase')."/wui/images/internal/move.png)\'"
+						." href=javascript:objid=".$obj['id'].";get_click(\'".$obj['type']."\',2,\'modify\');>"
+						."<span>".$this->LANG->getText('positionSize')."</span></a></li>";			
+		}
+		
+		// Delete link
+		$tooltipText .= "<li><a style=\'background-image:url(".$this->CORE->MAINCFG->getValue('paths','htmlbase')."/wui/images/internal/delete.png)\'"
+		  ." href=\'#\' id=\'delete_".$obj['type']."_".$obj['id']."\'"
+			." onClick=\'return deleteMapObject(this);return false;\'>"
+		  ."<span>".$this->LANG->getText('delete')."</span></a></li>";
+		
+		$tooltipText .= "</ul>";
+		$tooltipText .= "</th></tr>";
+		
+		
+		// Print configured settings
+		$tooltipText .= '<tr><th colspan=\\\'2\\\'>'.$this->LANG->getText('configured').'</th></tr>'.$configuredText;
+		
+		// Print inherited settings
+		$tooltipText .= '<tr class=\\\'inherited\\\'><th colspan=\\\'2\\\'>'.$this->LANG->getText('inherited').'</th></tr>'.$defaultText;
+		
+		$tooltipText .= '</table>';
+		
+		$info = "onmouseout=\"UnTip();\""
+		       ."onmouseover=\"Tip('".$tooltipText."',"
+		       ."DELAY,200,"
+		       ."STICKY,true,"
+		       ."OFFSETX,6,"
+		       ."OFFSETY,6,"
+		       ."CLICKCLOSE,true,"
+		       ."BORDERWIDTH,0,"
+		       ."BGCOLOR,'#FFFFFF');\"";
+		
+		return $info;
 	}
 	
 	/**
@@ -610,41 +663,79 @@ class WuiMap extends GlobalMap {
 	 * @author Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getJsLang() {
-		$ret = '';
-		$ret .= 'var langMenu = Array();';
-		$ret .= 'langMenu[\'save\'] = \''.$this->LANG->getLabel('save').'\';';
-		$ret .= 'langMenu[\'restore\'] = \''.$this->LANG->getLabel('restore').'\';';
-		$ret .= 'langMenu[\'properties\'] = \''.$this->LANG->getLabel('properties').'\';';
-		$ret .= 'langMenu[\'addObject\'] = \''.$this->LANG->getLabel('addObject').'\';';
-		$ret .= 'langMenu[\'nagVisConfig\'] = \''.$this->LANG->getLabel('nagVisConfig').'\';';
-		$ret .= 'langMenu[\'help\'] = \''.$this->LANG->getLabel('help').'\';';
-		$ret .= 'langMenu[\'open\'] = \''.$this->LANG->getLabel('open').'\';';
-		$ret .= 'langMenu[\'openInNagVis\'] = \''.$this->LANG->getLabel('openInNagVis').'\';';
-		$ret .= 'langMenu[\'manageMaps\'] = \''.$this->LANG->getLabel('manageMaps').'\';';
-		$ret .= 'langMenu[\'manageBackends\'] = \''.$this->LANG->getLabel('manageBackends').'\';';
-		$ret .= 'langMenu[\'manageBackgrounds\'] = \''.$this->LANG->getLabel('manageBackgrounds').'\';';
-		$ret .= 'langMenu[\'manageShapes\'] = \''.$this->LANG->getLabel('manageShapes').'\';';
-		$ret .= 'langMenu[\'icon\'] = \''.$this->LANG->getLabel('icon').'\';';
-		$ret .= 'langMenu[\'line\'] = \''.$this->LANG->getLabel('line').'\';';
-		$ret .= 'langMenu[\'special\'] = \''.$this->LANG->getLabel('special').'\';';
-		$ret .= 'langMenu[\'host\'] = \''.$this->LANG->getLabel('host').'\';';
-		$ret .= 'langMenu[\'service\'] = \''.$this->LANG->getLabel('service').'\';';
-		$ret .= 'langMenu[\'hostgroup\'] = \''.$this->LANG->getLabel('hostgroup').'\';';
-		$ret .= 'langMenu[\'servicegroup\'] = \''.$this->LANG->getLabel('servicegroup').'\';';
-		$ret .= 'langMenu[\'map\'] = \''.$this->LANG->getLabel('map').'\';';
-		$ret .= 'langMenu[\'textbox\'] = \''.$this->LANG->getLabel('textbox').'\';';
-		$ret .= 'langMenu[\'shape\'] = \''.$this->LANG->getLabel('shape').'\';';
-		$ret .= 'langMenu[\'manage\'] = \''.$this->LANG->getLabel('manage').'\';';
-		$ret .= 'var lang = Array();';
-		$ret .= 'lang[\'clickMapToSetPoints\'] = \''.$this->LANG->getMessageText('clickMapToSetPoints').'\';';
-		$ret .= 'lang[\'confirmDelete\'] = \''.$this->LANG->getMessageText('confirmDelete').'\';';
-		$ret .= 'lang[\'confirmRestore\'] = \''.$this->LANG->getMessageText('confirmRestore').'\';';
-		$ret .= 'lang[\'wrongValueFormat\'] = \''.$this->LANG->getMessageText('wrongValueFormat').'\';';
-		$ret .= 'lang[\'wrongValueFormatMap\'] = \''.$this->LANG->getMessageText('wrongValueFormatMap').'\';';
-		$ret .= 'lang[\'wrongValueFormatOption\'] = \''.$this->LANG->getMessageText('wrongValueFormatOption').'\';';
+		$langMenu = Array(
+			'overview' => $this->LANG->getText('overview'),
+			'restore' => $this->LANG->getText('restore'),
+			'properties' => $this->LANG->getText('properties'),
+			'addObject' => $this->LANG->getText('addObject'),
+			'nagVisConfig' => $this->LANG->getText('nagVisConfig'),
+			'help' => $this->LANG->getText('help'),
+			'open' => $this->LANG->getText('open'),
+			'openInNagVis' => $this->LANG->getText('openInNagVis'),
+			'manageMaps' => $this->LANG->getText('manageMaps'),
+			'manageBackends' => $this->LANG->getText('manageBackends'),
+			'manageBackgrounds' => $this->LANG->getText('manageBackgrounds'),
+			'manageShapes' => $this->LANG->getText('manageShapes'),
+			'icon' => $this->LANG->getText('icon'),
+			'line' => $this->LANG->getText('line'),
+			'special' => $this->LANG->getText('special'),
+			'host' => $this->LANG->getText('host'),
+			'service' => $this->LANG->getText('service'),
+			'hostgroup' => $this->LANG->getText('hostgroup'),
+			'servicegroup' => $this->LANG->getText('servicegroup'),
+			'map' => $this->LANG->getText('map'),
+			'textbox' => $this->LANG->getText('textbox'),
+			'shape' => $this->LANG->getText('shape'),
+			'manage' => $this->LANG->getText('manage'));
 		
+		$lang = Array(
+			'clickMapToSetPoints' => $this->LANG->getText('clickMapToSetPoints'),
+			'confirmDelete' => $this->LANG->getText('confirmDelete'),
+			'confirmRestore' => $this->LANG->getText('confirmRestore'),
+			'wrongValueFormat' => $this->LANG->getText('wrongValueFormat'),
+			'wrongValueFormatMap' => $this->LANG->getText('wrongValueFormatMap'),
+			'wrongValueFormatOption' => $this->LANG->getText('wrongValueFormatOption'),
+			'unableToWorkWithMap' => $this->LANG->getText('unableToWorkWithMap'),
+			'mustValueNotSet' => $this->LANG->getText('mustValueNotSet'),
+			'chosenLineTypeNotValid' => $this->LANG->getText('chosenLineTypeNotValid'),
+			'onlyLineOrIcon' => $this->LANG->getText('onlyLineOrIcon'),
+			'not2coordsX' => $this->LANG->getText('not2coords','COORD~X'),
+			'not2coordsY' => $this->LANG->getText('not2coords','COORD~Y'),
+			'only1or2coordsX' => $this->LANG->getText('only1or2coords','COORD~X'),
+			'only1or2coordsY' => $this->LANG->getText('only1or2coords','COORD~Y'),
+			'viewTypeWrong' => $this->LANG->getText('viewTypeWrong'),
+			'lineTypeNotSet' => $this->LANG->getText('lineTypeNotSet'),
+			'loopInMapRecursion' => $this->LANG->getText('loopInMapRecursion'),
+			'mapObjectWillShowSummaryState' => $this->LANG->getText('mapObjectWillShowSummaryState'),
+			'firstMustChoosePngImage' => $this->LANG->getText('firstMustChoosePngImage'),
+			'mustChooseValidImageFormat' => $this->LANG->getText('mustChooseValidImageFormat'),
+			'foundNoBackgroundToDelete' => $this->LANG->getText('foundNoBackgroundToDelete'),
+			'confirmBackgroundDeletion' => $this->LANG->getText('confirmBackgroundDeletion'),
+			'unableToDeleteBackground' => $this->LANG->getText('unableToDeleteBackground'),
+			'mustValueNotSet1' => $this->LANG->getText('mustValueNotSet1'),
+			'foundNoShapeToDelete' => $this->LANG->getText('foundNoShapeToDelete'),
+			'shapeInUse' => $this->LANG->getText('shapeInUse'),
+			'confirmShapeDeletion' => $this->LANG->getText('confirmShapeDeletion'),
+			'unableToDeleteShape' => $this->LANG->getText('unableToDeleteShape'),
+			'chooseMapName' => $this->LANG->getText('chooseMapName'),
+			'minOneUserAccess' => $this->LANG->getText('minOneUserAccess'),
+			'noMapToRename' => $this->LANG->getText('noMapToRename'),
+			'noNewNameGiven' => $this->LANG->getText('noNewNameGiven'),
+			'mapAlreadyExists' => $this->LANG->getText('mapAlreadyExists'),
+			'foundNoMapToDelete' => $this->LANG->getText('foundNoMapToDelete'),
+			'foundNoMapToExport' => $this->LANG->getText('foundNoMapToExport'),
+			'foundNoMapToImport' => $this->LANG->getText('foundNoMapToImport'),
+			'notCfgFile' => $this->LANG->getText('notCfgFile'),
+			'confirmNewMap' => $this->LANG->getText('confirmNewMap'),
+			'confirmMapRename' => $this->LANG->getText('confirmMapRename'),
+			'confirmMapDeletion' => $this->LANG->getText('confirmMapDeletion'),
+			'unableToDeleteMap' => $this->LANG->getText('unableToDeleteMap'),
+			'noPermissions' => $this->LANG->getText('noPermissions'),
+			'minOneUserWriteAccess' => $this->LANG->getText('minOneUserWriteAccess'),
+			'noSpaceAllowed' => $this->LANG->getText('noSpaceAllowed'),
+			'manualInput' => $this->LANG->getText('manualInput'));
 		
-		return $ret;	
+		return 'var langMenu = '.json_encode($langMenu).'; var lang = '.json_encode($lang).';';	
 	}
 	
 	/**
@@ -670,35 +761,14 @@ class WuiMap extends GlobalMap {
 	/**
 	 * Parses the invisible forms and JS arrays needed in WUI
 	 *
-	 * @return	Array Html
+	 * @return	String HTML Code
 	 * @author Lars Michelsen <lars@vertical-visions.de>
      */
 	function parseInvisible() {
-		$arr = Array();
-		
-		##################################
-		# important form. it makes possible to communicate the coordinates of all the objects to the server 
-		# Idea : when one drags and drops an object, the wz_dragdrop.js which handles this has been modified to update these hidden fields.
-		# At any time, the fields are filled like :
-		#    image : 2,5  (the numbers representing $key, which is the line number in the map .cfg file, counting from 0)
-		#    valx : 12,165
-		#    valy : 41,98
-		# this simple example represents 2 objects : obj1 (defined line 3 in the map.cfg file) x=12 y=41
-		#                                            obj2 (defined line 6 in the map.cfg file) x=165 y=98
-		# When the user clicks on the Save buton, these lists are passed to a bash script executed on the server, which will parse them and treat them.
-		# This is how it works to save the maps :)
-		$arr[] = '<form id="myvalues" style="display:none;" name="myvalues" action="./form_handler.php?myaction=save" method="post">
-			<input type="hidden" name="mapname" value="'.$this->MAPCFG->getName().'" />
-			<input type="hidden" name="image" value="" />
-			<input type="hidden" name="valx" value="" />
-			<input type="hidden" name="valy" value="" />
-			<input type="submit" name="submit" value="Save" />
-		</form>';
-		
-		$arr = array_merge($arr,$this->parseJs("
+		$str = $this->parseJs("
+			var oGeneralProperties = ".$this->CORE->MAINCFG->parseGeneralProperties().";
 			var mapname = '".$this->MAPCFG->getName()."';
 			var username = '".$this->MAINCFG->getRuntimeValue('user')."';
-			var autosave = '".$this->MAINCFG->getRuntimeValue('justAdded')."';
 			var mapOptions = ".$this->MAINCFG->getRuntimeValue('mapOptions').";
 			var backupAvailable = '".file_exists($this->MAINCFG->getValue('paths', 'mapcfg').$this->MAPCFG->getName().".cfg.bak")."';
 			
@@ -707,8 +777,8 @@ class WuiMap extends GlobalMap {
 			
 			// draw the shapes on the background
 			myshape_background.paint();
-			"));
+			");
 		
-		return $arr;
+		return $str;
 	}
 }
