@@ -26,7 +26,6 @@
  * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class WuiMapCfg extends GlobalMapCfg {
-	var $name;
 	
 	/**
 	 * Class Constructor
@@ -35,12 +34,15 @@ class WuiMapCfg extends GlobalMapCfg {
 	 * @param	String			$name		Name of the map
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function WuiMapCfg(&$MAINCFG,$name='') {
-		$this->MAINCFG = &$MAINCFG;
+	function WuiMapCfg(&$CORE, $name='') {
+		$this->CORE = &$CORE;
+		$this->MAINCFG = &$CORE->MAINCFG;
+		$this->LANG = &$CORE->LANG;
+		
 		$this->name	= $name;
 		
 		$this->getMap();
-		parent::GlobalMapCfg($MAINCFG,$this->name);
+		parent::__construct($CORE, $this->name);
 	}
 	
 	/**
@@ -57,6 +59,17 @@ class WuiMapCfg extends GlobalMapCfg {
 		$this->name = preg_replace("/[^a-zA-Z0-9_-]/",'',$this->name);
 	}
 	
+	/**
+	 * Gets all informations about an object type
+	 *
+	 * @param   String  Type to get the informations for
+	 * @return  Array   The validConfig array
+	 * @author  Lars Michelsen <lars@vertical-visions.de>
+	 */
+	function getValidObjectType($type) {
+		return $this->validConfig[$type];
+	}
+	
 	/**
 	 * Gets the valid configuration array
 	 *
@@ -104,8 +117,9 @@ class WuiMapCfg extends GlobalMapCfg {
 			if(unlink($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg')) {
 				return TRUE;
 			} else {
-				$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
-				$FRONTEND->messageToUser('ERROR','couldNotDeleteMapCfg','MAPPATH~'.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg');
+				if($printErr) {
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('couldNotDeleteMapCfg','MAPPATH~'.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg'));
+				}
 				return FALSE;
 			}
 		} else {
@@ -124,9 +138,8 @@ class WuiMapCfg extends GlobalMapCfg {
 		if($this->checkMapConfigExists($printErr) && is_writeable($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg')) {
 			return TRUE;
 		} else {
-			if($printErr == 1) {
-				$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
-				$FRONTEND->messageToUser('ERROR','mapCfgNotWriteable','MAP~'.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg');
+			if($printErr) {
+				new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('mapCfgNotWriteable','MAP~'.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg'));
 			}
 			return FALSE;
 		}
@@ -153,7 +166,7 @@ class WuiMapCfg extends GlobalMapCfg {
 			$done = FALSE;
 			while(isset($file[$l]) && $file[$l] != '' && $done == FALSE) {
 				// ignore comments
-				if(!ereg('^#',$file[$l]) && !ereg('^;',$file[$l])) {
+				if(!preg_match('/^#/',$file[$l]) && !preg_match('/^;/',$file[$l])) { 
 					$defineCln = explode('{', $file[$l]);
 					$define = explode(' ',$defineCln[0]);
 					// select only elements of the given type
@@ -167,15 +180,15 @@ class WuiMapCfg extends GlobalMapCfg {
 								// choose first parameter line
 								$l++;
 								
-								
-								// loop parameters from array
+								// Loop all parameters from array
 								foreach($this->mapConfig[$type][$id] AS $key => $val) {
 									// if key is not type
-									if($key != 'type') {
+									if($key != 'type' && $key != 'object_id') {
 										$cfgLines = 0;
 										$cfgLine = '';
 										$cfgLineNr = 0;
-										// Parameter aus Datei durchlaufen
+										
+										// Loop parameters from file (Find line for this option)
 										while(isset($file[($l+$cfgLines)]) && trim($file[($l+$cfgLines)]) != '}') {
 											$entry = explode('=',$file[$l+$cfgLines], 2);
 											if($key == trim($entry[0])) {
@@ -193,7 +206,8 @@ class WuiMapCfg extends GlobalMapCfg {
 											$file[$cfgLineNr] = $cfgLine;
 										} elseif($cfgLineNr != 0 && $val == '') {
 											// if a paremter is not in array or a value is empty, delete the line in the file
-											unset($file[$cfgLineNr]);
+											$file[$cfgLineNr] = '';
+											$cfgLines--;
 										} elseif($cfgLineNr == 0 && $val != '') {
 											// if a parameter is was not found in array and a value is not empty, create line
 											if(is_array($val)) {
@@ -236,11 +250,13 @@ class WuiMapCfg extends GlobalMapCfg {
 			
 			// reached end of file - couldn't find that element, create a new one...
 			if($done == FALSE) {
-				if($file[count($file)-1] != "\n") {
+				if(count($file) > 0 && $file[count($file)-1] != "\n") {
 					$file[] = "\n";
 				}
 				$file[] = 'define '.$type." {\n";
-				foreach($this->mapConfig[$type][$id] AS $key => $val) {
+				$aKeys = $this->getValidTypeKeys($type);
+				foreach($aKeys As $key) {
+					$val = $this->getValue($type, $id, $key, TRUE);
 					if(isset($val) && $val != '') {
 						$file[] = $key.'='.$val."\n";
 					}
@@ -266,72 +282,67 @@ class WuiMapCfg extends GlobalMapCfg {
 	 * @param	Boolean $printErr
 	 * @return	Array/Boolean   Is Successful?
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
-     */
-    function checkMapLocked($ignoreLock=0,$printErr=1) {
-	    if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::checkMapLocked('.$ignoreLock.','.$printErr.')');
-        // read lockfile
-        $lockdata = $this->readMapLock();
-        if(is_array($lockdata)) {
-            // check if the lock is older than 5 Minutes and don't ignore lock
-            if($lockdata['time'] > time() - $this->MAINCFG->getValue('wui','maplocktime') * 60) {
-                if($ignoreLock == 0) {
-                    // the lock should be ignored
-                        return FALSE;
-                } else {
-                    // there is a lock and it should be recognized
-                    // check if this is the lock of the current user (Happens e.g. by pressing F5)
-                    if($this->MAINCFG->getRuntimeValue('user') == $lockdata['user'] && $_SERVER['REMOTE_ADDR'] == $lockdata['ip']) {
-                        // refresh the lock (write a new lock)
-                        $this->writeMapLock();
-                        // it's locked by the current user, so it's not locked for him
-                        return FALSE;
-                    }
-                    if($printErr == 1) {
-                        $LANG = new GlobalLanguage($this->MAINCFG,'wui:global');
-                        
-                        // message the user that there is a lock by another user, the user can decide wether he want's to override it or not
-                        print '<script>if(!confirm(\''.$LANG->getMessageText('mapLocked','MAP~'.$this->name.',TIME~'.date('d.m.Y H:i',$lockdata['time']).',USER~'.$lockdata['user'].',IP~'.$lockdata['ip']).'\',\'\')) { history.back(); }</script>';
-    				}
-        				return TRUE;
-                }
-            } else {
-                // delete lockfile & continue
-                // try to delete map lock, if nothing to delete its OK
-                $this->deleteMapLock();
-                    return FALSE;
-            }
-        } else {
-            // no valid informations in lock or no lock there
-            // try to delete map lock, if nothing to delete its OK
-            $this->deleteMapLock();
-                return FALSE;
-        }
-    }
-    
+   */
+	function checkMapLocked($ignoreLock=0,$printErr=1) {
+		// read lockfile
+		$lockdata = $this->readMapLock();
+		if(is_array($lockdata)) {
+			// check if the lock is older than 5 Minutes and don't ignore lock
+			if($lockdata['time'] > time() - $this->MAINCFG->getValue('wui','maplocktime') * 60) {
+				if($ignoreLock == 0) {
+					// the lock should be ignored
+					return FALSE;
+				} else {
+					// there is a lock and it should be recognized
+					// check if this is the lock of the current user (Happens e.g. by pressing F5)
+					if($this->MAINCFG->getRuntimeValue('user') == $lockdata['user'] && $_SERVER['REMOTE_ADDR'] == $lockdata['ip']) {
+						// refresh the lock (write a new lock)
+						$this->writeMapLock();
+						// it's locked by the current user, so it's not locked for him
+						return FALSE;
+					}
+					if($printErr == 1) {
+						$LANG = new GlobalLanguage($this->MAINCFG,'nagvis');
+						
+						// message the user that there is a lock by another user, the user can decide wether he want's to override it or not
+						print '<script>if(!confirm(\''.$LANG->getText('mapLocked','MAP~'.$this->name.',TIME~'.date('d.m.Y H:i',$lockdata['time']).',USER~'.$lockdata['user'].',IP~'.$lockdata['ip']).'\',\'\')) { history.back(); }</script>';
+					}
+					return TRUE;
+				}
+			} else {
+				// delete lockfile & continue
+				// try to delete map lock, if nothing to delete its OK
+				$this->deleteMapLock();
+				return FALSE;
+			}
+		} else {
+			// no valid informations in lock or no lock there
+			// try to delete map lock, if nothing to delete its OK
+			$this->deleteMapLock();
+			return FALSE;
+		}
+	}
 	
 	/**
 	 * Reads the contents of the lockfile
 	 *
 	 * @return	Array/Boolean   Is Successful?
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
-     */
+	 */
 	function readMapLock() {
-	    if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::readMapLock()');
-	    if($this->checkMapLockReadable(0)) {
-	        $fileContent = file($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock');
-	        // only recognize the first line, explode it by :
-	        $arrContent = explode(':',$fileContent[0]);
-	        // if there are more elements in the array it is OK
-	        if(count($arrContent) > 0) {
-	            return Array('time' => $arrContent[0], 'user' => $arrContent[1], 'ip' => $arrContent[2]);
-	        } else {
-	            if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::readMapLock(): FALSE');
-	            return FALSE;
-	        }
-        } else {
-	        if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::readMapLock(): FALSE');
-	        return FALSE;
-	    }
+		if($this->checkMapLockReadable(0)) {
+			$fileContent = file($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock');
+			// only recognize the first line, explode it by :
+			$arrContent = explode(':',$fileContent[0]);
+			// if there are more elements in the array it is OK
+			if(count($arrContent) > 0) {
+				return Array('time' => $arrContent[0], 'user' => $arrContent[1], 'ip' => $arrContent[2]);
+			} else {
+				return FALSE;
+			}
+		} else {
+			return FALSE;
+		}
 	}
 	
 	/**
@@ -339,19 +350,17 @@ class WuiMapCfg extends GlobalMapCfg {
 	 *
 	 * @return	Boolean     Is Successful?
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
-     */
+	 */
 	function writeMapLock() {
-	    if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::writeMapLock()');
 		if($this->checkMapLockWriteable(0)) {
-		    // open file for writing and insert the needed informations
-		 	$fp = fopen($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock','w');
-		 	fwrite($fp,time().':'.$this->MAINCFG->getRuntimeValue('user').':'.$_SERVER['REMOTE_ADDR']);
-		 	fclose($fp);
-	 			return TRUE;
+			// open file for writing and insert the needed informations
+			$fp = fopen($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock','w');
+			fwrite($fp,time().':'.$this->MAINCFG->getRuntimeValue('user').':'.$_SERVER['REMOTE_ADDR']);
+			fclose($fp);
+			return TRUE;
 		} else {
-	        if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::writeMapLock(): FALSE');
-	        return FALSE;
-	    }
+			return FALSE;
+		}
 	}
 	
 	/**
@@ -359,23 +368,19 @@ class WuiMapCfg extends GlobalMapCfg {
 	 *
 	 * @return	Boolean     Is Successful?
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
-     */
+	 */
 	function deleteMapLock() {
-	    if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::deleteMapLock()');
-	    if($this->checkMapLockWriteable(0)) {
-	        if(unlink($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock')) {
-	            // map lock deleted => OK
-	            if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::deleteMapLock(): TRUE');
-	            return TRUE;
-	        } else {
-	            if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::deleteMapLock(): FALSE');
-	            return FALSE;
-	        }
-        } else {
-            // no map lock to delete => OK
-	        if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::deleteMapLock(): TRUE');
-	        return TRUE;   
-	    }
+		if($this->checkMapLockWriteable(0)) {
+			if(unlink($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock')) {
+				// map lock deleted => OK
+				return TRUE;
+			} else {
+				return FALSE;
+			}
+		} else {
+			// no map lock to delete => OK
+			return TRUE;   
+		}
 	}
 	
 	/**
@@ -390,9 +395,8 @@ class WuiMapCfg extends GlobalMapCfg {
 			if(file_exists($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock')) {
 				return TRUE;
 			} else {
-				if($printErr == 1) {
-					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:global'));
-		            $FRONTEND->messageToUser('ERROR','mapLockNotExists','MAP~'.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock');
+				if($printErr) {
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('mapLockNotExists','MAP~'.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock'));
 				}
 				return FALSE;
 			}
@@ -413,9 +417,8 @@ class WuiMapCfg extends GlobalMapCfg {
 			if($this->checkMapLockExists($printErr) && is_readable($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock')) {
 				return TRUE;
 			} else {
-				if($printErr == 1) {
-					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:global'));
-		            $FRONTEND->messageToUser('ERROR','mapLockNotReadable','MAP='.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock');
+				if($printErr) {
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('mapLockNotReadable','MAP='.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock'));
 				}
 				return FALSE;
 			}
@@ -436,9 +439,8 @@ class WuiMapCfg extends GlobalMapCfg {
 			if($this->checkMapLockExists($printErr) && is_writeable($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock')) {
 				return TRUE;
 			} else {
-				if($printErr == 1) {
-					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'wui:global'));
-		            $FRONTEND->messageToUser('ERROR','mapLockNotWriteable','MAP='.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock');
+				if($printErr) {
+					new GlobalFrontendMessage('ERROR', $this->CORE->LANG->getText('mapLockNotWriteable','MAP='.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.lock'));
 				}
 				return FALSE;
 			}
