@@ -34,8 +34,24 @@ function checkPng(imageName) {
 	}
 }
 
+function checkJpg(imageName) {
+	if(imageName.substring(imageName.length-3,imageName.length).toLowerCase() != 'jpg') {
+		return false; 
+	} else {
+		return true;
+	}
+}
+
+function checkGif(imageName) {
+	if(imageName.substring(imageName.length-3,imageName.length).toLowerCase() != 'gif') {
+		return false; 
+	} else {
+		return true;
+	}
+}
+
 function checkImageUsed(imageName,mapOptions) {
-	for(var i=0;i<mapOptions.length;i++) {
+	for(var i=0, len = mapOptions.length; i< len; i++) {
 		if(mapOptions[i].mapImage == imageName) {
 			return mapOptions[i].mapName;
 		}
@@ -73,13 +89,11 @@ function check_image_create() {
 function check_image_add() {
 	if(document.new_image.image_file.value.length == 0) {
 		alert(printLang(lang['firstMustChoosePngImage'],''));
-		
 		return false;
 	}
 	
-	if(!checkPng(document.new_image.image_file.value)) {
-		alert(printLang(lang['mustChoosePngImage'],''));
-		
+	if(!checkPng(document.new_image.image_file.value) && !checkJpg(document.new_image.image_file.value) && !checkGif(document.new_image.image_file.value)) {
+		alert(printLang(lang['mustChooseValidImageFormat'],''));
 		return false;
 	}
 	
@@ -93,8 +107,8 @@ function check_image_delete() {
 		return false;
 	}
 	
-	imageUsedBy = checkImageUsed(document.image_delete.map_image.value, window.opener.mapOptions);
-	if(imageUsedBy != "") {
+	var imageUsedBy = checkImageUsed(document.image_delete.map_image.value, mapOptions);
+	if(imageUsedBy !== "") {
 		alert(printLang(lang['unableToDeleteBackground'],'MAP~'+imageUsedBy+',IMAGENAME~'+document.image_delete.map_image.value));
 		return false;
 	}
@@ -104,4 +118,4 @@ function check_image_delete() {
 	}
 	
 	return true;
-}
\ No newline at end of file
+}
