@@ -25,24 +25,23 @@
  * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 
-function getServices(backend_id,type,host_name,field,selected) {
+function getServices(backend_id, type, host_name, field, selected) {
+	// Only update services when host is not empty and not "Manual input..."
+	if(host_name != '' && host_name != lang['manualInput']) {
+		var oOpt = Object();
+		oOpt.field = field;
+		oOpt.selected = selected;
+		oOpt.type = type;
+		
+		printObjects(getSyncRequest('ajax_handler.php?action=getServices&backend_id='+backend_id+'&host_name='+host_name), oOpt);
+	}
+}
+
+function getObjects(backend_id, type, field, selected) {
 	var oOpt = Object();
 	oOpt.field = field;
 	oOpt.selected = selected;
 	oOpt.type = type;
-	getRequest('ajax_handler.php?action=getServices&backend_id='+backend_id+'&host_name='+host_name,'printObjects',oOpt);
-}
-
-function getObjects(backend_id,type,field,selected) {
-	var oOpt = Object();
-	oOpt.field = field;
-	oOpt.selected = selected;
-	oOpt.type = type;
-	getRequest('ajax_handler.php?action=getObjects&backend_id='+backend_id+'&type='+type,'printObjects',oOpt);
-}
-
-function getBackendOptions(backend_type,backend_id,form) {
-	var oOpt = Object();
-	oOpt.form = form;
-	getRequest('ajax_handler.php?action=getBackendOptions&backend_id='+backend_id+'&backend_type='+backend_type,'printBackendOptions',oOpt);
+	
+	printObjects(getSyncRequest('ajax_handler.php?action=getObjects&backend_id='+backend_id+'&type='+type), oOpt);
 }
\ No newline at end of file
