@@ -1,21 +1,20 @@
-/* This notice must be untouched at all times.
+/* This notice must be untouched at all times, and must not be removed.
 
-wz_dragdrop.js	v. 4.87
+wz_dragdrop.js	v. 4.91
 The latest version is available at
 http://www.walterzorn.com
 or http://www.devira.com
 or http://www.walterzorn.de
 
-Copyright (c) 2002-2003 Walter Zorn. All rights reserved.
+Copyright (c) Walter Zorn. All rights reserved.
 Created 26. 8. 2002 by Walter Zorn (Web: http://www.walterzorn.com )
-Last modified: 29. 11. 2006
+Last modified: 10.10.2008
 
-This DHTML & Drag&Drop Library adds Drag&Drop functionality
-to the following types of html-elements:
-- images, even if not positioned via layers,
-  nor via stylesheets or any other kind of "hard-coding"
+This DHTML & Drag&Drop Library adds Drag&Drop functionality to:
+- images, even those not positioned via layers,
+  nor via stylesheets or any other kind of "hard-coding";
 - relatively and absolutely positioned layers (DIV elements).
-Moreover, it provides extended DHTML abilities.
+Moreover, it provides extended DHTML capabilities.
 
 LICENSE: LGPL
 
@@ -104,7 +103,8 @@ function WZDD()
 	this.w3c = !!(!this.op && !this.ie && !this.n6 && document.getElementById);
 	this.ce = !!(document.captureEvents && document.releaseEvents && !this.n6);
 	this.px = this.n4? '' : 'px';
-	this.tiv = this.w3c? 40 : 10;
+	this.tWait = this.w3c? 40 : 10;
+	this.noRecalc = false;
 }
 var dd = new WZDD();
 
@@ -352,7 +352,9 @@ dd.addProps = function(d_o)
 		if(!d_o.noalt && !dd.noalt && d_o.nimg && d_o.oimg)
 		{
 			d_o.nimg.alt = d_o.oimg.alt || '';
-			if(d_o.oimg.title) d_o.nimg.title = d_o.oimg.title;
+			d_o.nimg.title = d_o.oimg.title;
+			d_o.nimg.onmouseover = d_o.oimg.onmouseover;
+			d_o.nimg.onmouseout = d_o.oimg.onmouseout;
 		}
 		d_o.bgColor = '';
 	}
@@ -396,8 +398,10 @@ dd.finlz = function()
 {
 	if(dd.ie && dd.elements)
 	{
+		dd.noRecalc = true;
 		for(var d_i = dd.elements.length; d_i;)
 			dd.elements[--d_i].del();
+		dd.noRecalc = false;
 	}
 	if(dd.uloadFunc) dd.uloadFunc();
 };
@@ -467,6 +471,7 @@ dd.getEventTarget = function(d_e, d_s, d_n)
 };
 dd.recalc = function(d_x)
 {
+	if(dd.noRecalc) return;
 	for(var d_o, d_i = dd.elements.length; d_i;)
 	{
 		if(!(d_o = dd.elements[--d_i]).is_image && d_o.div)
@@ -576,7 +581,7 @@ function DDObj(d_o, d_i)
 		if(this.div)
 		{
 			this.div.ddObj = this;
-			this.div.pos_rel = ("" + (this.div.parentNode? this.div.parentNode.tagName : this.div.parentElement? this.div.parentElement.tagName : '').toLowerCase().indexOf('body') < 0);
+			this.div.pos_rel = dd.getCssProp(this.div, 'position','position','position') == "relative";
 		}
 		dd.getPageXY(this.div);
 		this.defx = this.x = dd.x;
@@ -803,10 +808,10 @@ DDObj.prototype.addChild = function(d_kd, detach, defp)
 		d_kd.defz = d_kd.defz+this.defz-(d_kd.parent? d_kd.parent.defz : 0)+(!d_kd.is_image*1);
 		d_kd.setZ(d_kd.z+this.z-(d_kd.parent? d_kd.parent.z : 0)+(!d_kd.is_image*1), 1);
 	}
-	if(d_kd.parent) d_kd.parent._removeChild(d_kd, 1);
+	if(d_kd.parent) d_kd.parent.removeChild(d_kd, 1);
 	d_kd.parent = this;
 };
-DDObj.prototype._removeChild = function(d_kd, d_newp)
+DDObj.prototype.removeChild = function(d_kd, d_newp)
 {
 	if(typeof d_kd != "object") d_kd = this.children[d_kd];
 	var d_oc = this.children, d_nc = new Array();
@@ -862,9 +867,9 @@ DDObj.prototype._setOpaRel = function(d_x, d_kd, d_y, d_o)
 	{
 		d_y = this.opacity*d_x;
 		if(typeof this.css.MozOpacity != dd_u) this.css.MozOpacity = d_y;
+		else if (typeof this.css.opacity != dd_u) this.css.opacity = d_y;
 		else if(typeof this.css.filter != dd_u)
 			this.css.filter = "Alpha(opacity="+parseInt(100*d_y)+")";
-		else this.css.opacity = d_y;
 		for(var d_i = this.children.length; d_i;)
 			if(!(d_o = this.children[--d_i]).detached) d_o._setOpaRel(d_x, 1);
 	}
@@ -921,7 +926,7 @@ DDObj.prototype.getEltBelow = function(d_ret, d_x, d_y)
 DDObj.prototype.del = function(d_os, d_o)
 {
 	var d_i, d_l;
-	if(this.parent && this.parent._removeChild) this.parent._removeChild(this);
+	if(this.parent && this.parent.removeChild) this.parent.removeChild(this);
 	if(this.original)
 	{
 		this.hide();
@@ -1211,7 +1216,7 @@ function DRAG(d_ev)
 	{
 		if(dd.wait) return false;
 		dd.wait = 1;
-		setTimeout('dd.wait = 0;', dd.tiv);
+		setTimeout('dd.wait = 0;', dd.tWait);
 	}
 	dd.e = new dd.evt(d_ev);
 	if(dd.ie && !dd.e.but)
@@ -1235,7 +1240,7 @@ function RESIZE(d_ev)
 	if(!dd.obj || !dd.obj.visible) return true;
 	if(dd.wait) return false;
 	dd.wait = 1;
-	setTimeout('dd.wait = 0;', dd.tiv);
+	setTimeout('dd.wait = 0;', dd.tWait);
 	dd.e = new dd.evt(d_ev);
 	if(dd.ie && !dd.e.but)
 	{
@@ -1337,21 +1342,20 @@ function SET_DHTML()
 	window.onunload = dd.finlz;
 	dd.setDwnHdl(PICK);
 }
-function ADD_DHTML(d_o) // layers only!
+function ADD_DHTML() // layers only!
 {
-	d_o = new DDObj(d_o);
-	dd.addElt(d_o);
-	dd.addProps(d_o);
+	var d_a = arguments, d_o, d_i = d_a.length; while(d_i)
+	{
+		d_o = new DDObj(d_a[--d_i]);
+		dd.addElt(d_o);
+		dd.addProps(d_o);
+	}
 	dd.mkWzDom();
 }
 
-
-
-
 ////////////////////////////////////////////////////////////
 // If not needed, all code below this line may be removed
 
-
 // For backward compatibility
 dd.d = document;			// < v. 2.72
 var RESET_ZINDEX = RESET_Z; // < 3.44
@@ -1359,16 +1363,11 @@ var KEYDOWN_RESIZE = RESIZABLE; // < 4.43
 var CURSOR_POINTER = CURSOR_HAND; // < 4.44
 var NO_SCROLL = '';		 // < v. 4.49
 
-
-
-
 ////////////////////////////////////////////////////////////
 // FUNCTIONS FOR EXTENDED SCRIPTING
 // Use these for your own extensions,
 // or to call functions defined elsewhere
 
-
-
 /* my_PickFunc IS AUTOMATICALLY CALLED WHEN AN ITEM STARTS TO BE DRAGGED.
 The following objects/properties are accessible from here:
 
@@ -1393,98 +1392,27 @@ The following objects/properties are accessible from here:
 For more properties and details, visit the API documentation
 at http://www.walterzorn.com/dragdrop/api_e.htm (english) or
 http://www.walterzorn.de/dragdrop/api.htm (german)	*/
-function my_PickFunc()
-{
-	// Save old coords
-	dd.obj.oldX = dd.obj.x;
-	dd.obj.oldY = dd.obj.y;
-	
-	// Check if this is a box
-	if(dd.obj.name.search('box_') != -1) {
-		// When this object has a relative coordinated label, then move this too
-		var sLabelName = dd.obj.name.replace('box_','rel_label_');
-		var oLabel = document.getElementById(sLabelName);
-		if(oLabel) {
-			ADD_DHTML(sLabelName);
-			dd.obj.addChild(sLabelName);
-		}
-	}
+function my_PickFunc() {
+	// Call NagVis specific functions
+	moveMapObject(dd.obj);
 }
 
-
-
-
 /* my_DragFunc IS CALLED WHILE AN ITEM IS DRAGGED
 See the description of my_PickFunc above for what's accessible from here. */
-function my_DragFunc()
-{
-	//window.status = 'dd.elements.' + dd.obj.name + '.x  = ' + dd.obj.x + '	 dd.elements.' + dd.obj.name + '.y = ' + dd.obj.y;
+function my_DragFunc() {
+	dragMapObject(dd.obj);
 }
 
-
-
-
 /* my_ResizeFunc IS CALLED WHILE AN ITEM IS RESIZED
 See the description of my_PickFunc above for what's accessible from here. */
-function my_ResizeFunc()
-{
-	//window.status = 'dd.elements.' + dd.obj.name + '.w  = ' + dd.obj.w + '	 dd.elements.' + dd.obj.name + '.h = ' + dd.obj.h;
-}
+function my_ResizeFunc() {}
 
 /* THIS ONE IS CALLED ONCE AN ITEM IS DROPPED
 See the description of my_PickFunc for what's accessible from here.
 Here may be investigated, for example, what's the name (dd.obj.name)
 of the dropped item, and where (dd.obj.x, dd.obj.y) it has been dropped... */
 
-
-/*
-When we drop the object, we compute the lists image,valx and valy, that we write in hidden fields of a form in the webpage
-For example :
-	image : 2,5  (the numbers representing $key, which is the line number in the map .cfg file, counting from 0)
-	valx : 12,165
-	valy : 41,98
-would represent 2 objects : obj1 (defined line 3 in the map.cfg file) x=12 y=41
-                            obj2 (defined line 6 in the map.cfg file) x=165 y=98
-*/
 function my_DropFunc() {
-	window.status = "";
-
-	var names = "";
-	var coord_x = "";
-	var coord_y = "";
-	
-	// When x or y are negative just return this and make no change
-	if(dd.obj.y < 0 || dd.obj.x < 0) {
-		dd.obj.moveTo(dd.obj.oldX, dd.obj.oldY);
-		return;
-	}
-	
-	// Dragging of relative labels is not allowed, revert it
-	if(dd.obj.name.search('rel_label_') != -1) {
-		dd.obj.moveTo(dd.obj.oldX, dd.obj.oldY);
-		return;
-	}
-	
-	for (cpt = dd.elements.length - 1; cpt >=0  ; cpt--) {
-		names = names + dd.elements[cpt].name.replace("box_","") + ",";
-		myposx = dd.elements[cpt].x;
-		myposy = dd.elements[cpt].y;
-		coord_x = coord_x + myposx + ",";
-		coord_y = coord_y + myposy + ",";
-	}
-	
-	// we remove the final comma
-	names = names.substr(0,names.length -1);
-	coord_x = coord_x.substr(0,coord_x.length -1);
-	coord_y = coord_y.substr(0,coord_y.length -1);
-	
-	// we store these lists in the hidden fields of the "Save" form
-	document.myvalues.image.value = names;
-	document.myvalues.valx.value = coord_x;
-	document.myvalues.valy.value = coord_y;
-	
-	// if autosave is enabled we submit the form "Save" which will save and refresh the map
-	if(autosave == true) {
-		document.myvalues.submit.click();
-	}
+	// Call NagVis specific functions
+	saveObjectAfterMoveAndDrop(dd.obj);
 }
